@@ -1,47 +1,55 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python
 # -*- mode: python; coding: utf-8; -*-
-##---------------------------------------------------------------------------##
-##
-## Copyright (C) 1998-2003 Markus Franz Xaver Johannes Oberhumer
-## Copyright (C) 2003 Mt. Hood Playing Card Co.
-## Copyright (C) 2005-2009 Skomoroh
-##
-## This program is free software: you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation, either version 3 of the License, or
-## (at your option) any later version.
-##
-## This program is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
-##
-## You should have received a copy of the GNU General Public License
-## along with this program.  If not, see <http://www.gnu.org/licenses/>.
-##
-##---------------------------------------------------------------------------##
-
-__all__ = []
+# ---------------------------------------------------------------------------##
+#
+# Copyright (C) 1998-2003 Markus Franz Xaver Johannes Oberhumer
+# Copyright (C) 2003 Mt. Hood Playing Card Co.
+# Copyright (C) 2005-2009 Skomoroh
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# ---------------------------------------------------------------------------##
 
 # imports
-import sys
 
 # PySol imports
 from pysollib.gamedb import registerGame, GameInfo, GI
-from pysollib.util import *
-from pysollib.stack import *
 from pysollib.game import Game
 from pysollib.layout import Layout
-from pysollib.hint import AbstractHint, DefaultHint, CautiousDefaultHint
+from pysollib.hint import DefaultHint
+
+from pysollib.util import ACE, NO_SUIT
+
+from pysollib.stack import \
+        BasicRowStack, \
+        InitialDealTalonStack, \
+        InvisibleStack, \
+        Stack, \
+        StackWrapper, \
+        TalonStack, \
+        WasteStack, \
+        WasteTalonStack
 
 # ************************************************************************
 # *
 # ************************************************************************
 
+
 class Montana_Hint(DefaultHint):
     def computeHints(self):
         game = self.game
-        RLEN, RSTEP, RBASE = game.RLEN, game.RSTEP, game.RBASE
+        RSTEP, RBASE = game.RSTEP, game.RBASE
         freerows = [s for s in game.s.rows if not s.cards]
         # for each stack
         for r in game.s.rows:
@@ -54,7 +62,8 @@ class Montana_Hint(DefaultHint):
             else:
                 left = None
                 if c.rank == RBASE:
-                    # do not move the leftmost card of a row if the rank is correct
+                    # do not move the leftmost card of a row if the
+                    # rank is correct
                     continue
             for t in freerows:
                 if self.shallMovePile(r, t, pile, rpile):
@@ -81,14 +90,15 @@ class Montana_Talon(TalonStack):
     def dealCards(self, sound=False):
         # move cards to the Talon, shuffle and redeal
         game = self.game
-        RLEN, RSTEP, RBASE = game.RLEN, game.RSTEP, game.RBASE
+        decks = game.gameinfo.decks
+        RSTEP, RBASE = game.RSTEP, game.RBASE
         num_cards = 0
         assert len(self.cards) == 0
         rows = game.s.rows
         # move out-of-sequence cards from the Tableau to the Talon
         stacks = []
-        gaps = [None] * 4
-        for g in range(4):
+        gaps = [None] * 4 * decks
+        for g in range(4*decks):
             i = g * RSTEP
             r = rows[i]
             if r.cards and r.cards[-1].rank == RBASE:
@@ -99,7 +109,7 @@ class Montana_Talon(TalonStack):
                 r = rows[i + j]
                 if in_sequence:
                     if (not r.cards or
-                        not self._inSequence(r.cards[-1], suit, RBASE+j)):
+                            not self._inSequence(r.cards[-1], suit, RBASE+j)):
                         in_sequence = 0
                 if not in_sequence:
                     stacks.append(r)
@@ -120,7 +130,7 @@ class Montana_Talon(TalonStack):
         game.nextRoundMove(self)
         spaces = self.getRedealSpaces(stacks, gaps)
         for r in stacks:
-            if not r in spaces:
+            if r not in spaces:
                 self.game.moveMove(1, self, r, frames=4)
         # done
         assert len(self.cards) == 0
@@ -140,7 +150,8 @@ class Montana_RowStack(BasicRowStack):
         if self.id % self.game.RSTEP == 0:
             return cards[0].rank == self.game.RBASE
         left = self.game.s.rows[self.id - 1]
-        return left.cards and left.cards[-1].suit == cards[0].suit and left.cards[-1].rank + 1 == cards[0].rank
+        return left.cards and left.cards[-1].suit == cards[0].suit \
+            and left.cards[-1].rank + 1 == cards[0].rank
 
     def clickHandler(self, event):
         if not self.cards:
@@ -181,7 +192,7 @@ class Montana(Game):
                                   max_accept=1, max_cards=1))
                     x += l.XS
         if round_text:
-            x, y = l.XM + (self.RSTEP-1)*l.XS/2, self.height-l.YS
+            x, y = l.XM + (self.RSTEP-1)*l.XS//2, self.height-l.YS
             s.talon = self.Talon_Class(x, y, self)
             l.createRoundText(s.talon, 'se')
         else:
@@ -195,7 +206,6 @@ class Montana(Game):
         # define stack-groups
         l.defaultStackGroups()
 
-
     #
     # game overrides
     #
@@ -220,7 +230,8 @@ class Montana(Game):
             suit = rows[i].cards[-1].suit
             for j in range(self.RSTEP - 1):
                 r = rows[i + j]
-                if not r.cards or r.cards[-1].rank != self.RBASE + j or r.cards[-1].suit != suit:
+                if not r.cards or r.cards[-1].rank != self.RBASE + j \
+                        or r.cards[-1].suit != suit:
                     return False
         return True
 
@@ -234,7 +245,8 @@ class Montana(Game):
 
     def getQuickPlayScore(self, ncards, from_stack, to_stack):
         if from_stack.cards:
-            if from_stack.id % self.RSTEP == 0 and from_stack.cards[-1].rank == self.RBASE:
+            if from_stack.id % self.RSTEP == 0 and \
+                    from_stack.cards[-1].rank == self.RBASE:
                 # do not move the leftmost card of a row if the rank is correct
                 return -1
         return 1
@@ -251,10 +263,11 @@ class Spaces_Talon(Montana_Talon):
         spaces = []
         while len(spaces) != 4:
             r = self.game.random.choice(stacks)
-            if not r in spaces:
+            if r not in spaces:
                 spaces.append(r)
         return spaces
 
+
 class Spaces(Montana):
     Talon_Class = StackWrapper(Spaces_Talon, max_rounds=3)
 
@@ -269,13 +282,14 @@ class BlueMoon(Montana):
     def startGame(self):
         frames = 0
         for i in range(self.RLEN):
-            if i == self.RLEN-self.RSTEP: # last row
+            if i == self.RLEN-self.RSTEP:  # last row
                 self.startDealSample()
                 frames = -1
             if i % self.RSTEP == 0:     # left column
                 continue
             self.s.talon.dealRow(rows=(self.s.rows[i],), frames=frames)
-        ace_rows = [r for r in self.s.rows if r.cards and r.cards[-1].rank == ACE]
+        ace_rows = [r for r in self.s.rows
+                    if r.cards and r.cards[-1].rank == ACE]
         j = 0
         for r in ace_rows:
             self.moveMove(1, r, self.s.rows[j])
@@ -289,14 +303,16 @@ class BlueMoon(Montana):
 class RedMoon(BlueMoon):
     def _shuffleHook(self, cards):
         # move Aces to top of the Talon (i.e. first cards to be dealt)
-        return self._shuffleHookMoveToTop(cards, lambda c: (c.rank == 0, c.suit))
+        return self._shuffleHookMoveToTop(
+            cards, lambda c: (c.rank == 0, c.suit))
 
     def startGame(self):
+        decks = self.gameinfo.decks
         frames = 0
         r = self.s.rows
-        self.s.talon.dealRow(rows=(r[0],r[14],r[28],r[42]), frames=frames)
-        for i in range(4):
-            if i == 3:
+        self.s.talon.dealRow(rows=(r[::14]), frames=frames)
+        for i in range(4*decks):
+            if i == 4*decks-1:
                 self.startDealSample()
                 frames = 4
             n = i * 14 + 2
@@ -310,7 +326,8 @@ class RedMoon(BlueMoon):
 
 class Galary_Hint(Montana_Hint):
     def shallMovePile(self, from_stack, to_stack, pile, rpile):
-        if from_stack is to_stack or not to_stack.acceptsCards(from_stack, pile):
+        if from_stack is to_stack or \
+                not to_stack.acceptsCards(from_stack, pile):
             return False
         # now check for loops
         rr = self.ClonedStack(from_stack, stackcards=rpile)
@@ -330,12 +347,12 @@ class Galary_RowStack(Montana_RowStack):
         r = self.game.s.rows
         left = r[self.id - 1]
         if left.cards and left.cards[-1].suit == cards[0].suit \
-               and left.cards[-1].rank + 1 == cards[0].rank:
+                and left.cards[-1].rank + 1 == cards[0].rank:
             return True
         if self.id < len(r)-1:
             right = r[self.id + 1]
             if right.cards and right.cards[-1].suit == cards[0].suit \
-                   and right.cards[-1].rank - 1 == cards[0].rank:
+                    and right.cards[-1].rank - 1 == cards[0].rank:
                 return True
         return False
 
@@ -367,6 +384,7 @@ class Jungle_RowStack(Montana_RowStack):
         left = self.game.s.rows[self.id - 1]
         return left.cards and left.cards[-1].rank + 1 == cards[0].rank
 
+
 class Jungle(BlueMoon):
     Talon_Class = StackWrapper(Montana_Talon, max_rounds=2)
     RowStack_Class = Jungle_RowStack
@@ -384,7 +402,8 @@ class SpacesAndAces_RowStack(Montana_RowStack):
         if self.id % self.game.RSTEP == 0:
             return cards[0].rank == self.game.RBASE
         left = self.game.s.rows[self.id - 1]
-        return left.cards and left.cards[-1].suit == cards[0].suit and left.cards[-1].rank < cards[0].rank
+        return left.cards and left.cards[-1].suit == cards[0].suit \
+            and left.cards[-1].rank < cards[0].rank
 
 
 class SpacesAndAces(BlueMoon):
@@ -398,7 +417,7 @@ class SpacesAndAces(BlueMoon):
     def startGame(self):
         frames = 0
         for i in range(self.RLEN):
-            if i == self.RLEN-self.RSTEP: # last row
+            if i == self.RLEN-self.RSTEP:  # last row
                 self.startDealSample()
                 frames = -1
             if i % self.RSTEP == 0:     # left column
@@ -409,6 +428,7 @@ class SpacesAndAces(BlueMoon):
 # * Paganini
 # ************************************************************************
 
+
 class Paganini_Talon(Montana_Talon):
     def _inSequence(self, card, suit, rank):
         card_rank = card.rank
@@ -416,6 +436,7 @@ class Paganini_Talon(Montana_Talon):
             card_rank -= 4
         return card.suit == suit and card_rank == rank
 
+
 class Paganini_RowStack(Montana_RowStack):
     def acceptsCards(self, from_stack, cards):
         if not BasicRowStack.acceptsCards(self, from_stack, cards):
@@ -431,6 +452,7 @@ class Paganini_RowStack(Montana_RowStack):
             return cards[0].rank == 5
         return left.cards[-1].rank+1 == cards[0].rank
 
+
 class Paganini(BlueMoon):
     RLEN, RSTEP, RBASE = 40, 10, 0
 
@@ -462,7 +484,7 @@ class Paganini(BlueMoon):
 
 class Spoilt_RowStack(BasicRowStack):
     def acceptsCards(self, from_stack, cards):
-        #if not BasicRowStack.acceptsCards(self, from_stack, cards):
+        # if not BasicRowStack.acceptsCards(self, from_stack, cards):
         #    return False
 
         card = cards[0]
@@ -531,7 +553,7 @@ class Spoilt(Game):
                 s.rows.append(Spoilt_RowStack(x, y, self,
                               max_accept=1, max_cards=2, min_cards=1))
                 x += l.XS
-        x, y = self.width/2 - l.XS, self.height-l.YS
+        x, y = self.width//2 - l.XS, self.height-l.YS
         s.talon = WasteTalonStack(x, y, self, max_rounds=1)
         l.createText(s.talon, 'n')
         x += l.XS
@@ -580,7 +602,7 @@ class DoubleMontana(Montana):
     def startGame(self):
         frames = 0
         for i in range(self.RLEN):
-            if i == self.RLEN-self.RSTEP: # last row
+            if i == self.RLEN-self.RSTEP:  # last row
                 self.startDealSample()
                 frames = -1
             if i % self.RSTEP == 0:     # left column
@@ -588,6 +610,24 @@ class DoubleMontana(Montana):
             self.s.talon.dealRow(rows=(self.s.rows[i],), frames=frames)
 
 
+class DoubleBlueMoon(DoubleMontana, BlueMoon):
+    Talon_Class = StackWrapper(Montana_Talon, max_rounds=3)
+    RLEN, RSTEP, RBASE = 112, 14, 0
+
+    def createGame(self):
+        BlueMoon.createGame(self, round_text=True)
+    startGame = BlueMoon.startGame
+
+
+class DoubleRedMoon(DoubleMontana, RedMoon):
+    Talon_Class = StackWrapper(Montana_Talon, max_rounds=3)
+    RLEN, RROWS = 112, 8
+    _shuffleHook = RedMoon._shuffleHook
+
+    def createGame(self):
+        RedMoon.createGame(self, round_text=True)
+    startGame = RedMoon.startGame
+
 
 # register the game
 registerGame(GameInfo(53, Montana, "Montana",
@@ -598,13 +638,15 @@ registerGame(GameInfo(116, Spaces, "Spaces",
                       si={"ncards": 48}))
 registerGame(GameInfo(63, BlueMoon, "Blue Moon",
                       GI.GT_MONTANA | GI.GT_OPEN, 1, 2, GI.SL_MOSTLY_SKILL,
-                      altnames=("Rangoon",) ))
+                      altnames=("Rangoon",)))
 registerGame(GameInfo(117, RedMoon, "Red Moon",
                       GI.GT_MONTANA | GI.GT_OPEN, 1, 2, GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(275, Galary, "Galary",
-                      GI.GT_MONTANA | GI.GT_OPEN | GI.GT_ORIGINAL, 1, 2, GI.SL_MOSTLY_SKILL))
+                      GI.GT_MONTANA | GI.GT_OPEN | GI.GT_ORIGINAL, 1, 2,
+                      GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(276, Moonlight, "Moonlight",
-                      GI.GT_MONTANA | GI.GT_OPEN | GI.GT_ORIGINAL, 1, 2, GI.SL_MOSTLY_SKILL,
+                      GI.GT_MONTANA | GI.GT_OPEN | GI.GT_ORIGINAL, 1, 2,
+                      GI.SL_MOSTLY_SKILL,
                       si={"ncards": 48}))
 registerGame(GameInfo(380, Jungle, "Jungle",
                       GI.GT_MONTANA | GI.GT_OPEN, 1, 1, GI.SL_MOSTLY_SKILL))
@@ -613,12 +655,14 @@ registerGame(GameInfo(381, SpacesAndAces, "Spaces and Aces",
 registerGame(GameInfo(706, Paganini, "Paganini",
                       GI.GT_MONTANA | GI.GT_OPEN, 1, 1, GI.SL_MOSTLY_SKILL,
                       ranks=(0, 5, 6, 7, 8, 9, 10, 11, 12),
-                      altnames=('Long Trip',) ))
+                      altnames=('Long Trip',)))
 registerGame(GameInfo(736, Spoilt, "Spoilt",
                       GI.GT_MONTANA, 1, 0, GI.SL_MOSTLY_LUCK,
                       ranks=(0, 6, 7, 8, 9, 10, 11, 12),
                       ))
 registerGame(GameInfo(759, DoubleMontana, "Double Montana",
                       GI.GT_MONTANA | GI.GT_OPEN, 2, 0, GI.SL_MOSTLY_SKILL))
-
-
+registerGame(GameInfo(770, DoubleBlueMoon, "Double Blue Moon",
+                      GI.GT_MONTANA | GI.GT_OPEN, 2, 2, GI.SL_MOSTLY_SKILL))
+registerGame(GameInfo(771, DoubleRedMoon, "Double Red Moon",
+                      GI.GT_MONTANA | GI.GT_OPEN, 2, 2, GI.SL_MOSTLY_SKILL))
