@@ -1,40 +1,54 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python
 # -*- mode: python; coding: utf-8; -*-
-##---------------------------------------------------------------------------##
-##
-## Copyright (C) 1998-2003 Markus Franz Xaver Johannes Oberhumer
-## Copyright (C) 2003 Mt. Hood Playing Card Co.
-## Copyright (C) 2005-2009 Skomoroh
-##
-## This program is free software: you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation, either version 3 of the License, or
-## (at your option) any later version.
-##
-## This program is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
-##
-## You should have received a copy of the GNU General Public License
-## along with this program.  If not, see <http://www.gnu.org/licenses/>.
-##
-##---------------------------------------------------------------------------##
-
-__all__ = []
+# ---------------------------------------------------------------------------
+#
+# Copyright (C) 1998-2003 Markus Franz Xaver Johannes Oberhumer
+# Copyright (C) 2003 Mt. Hood Playing Card Co.
+# Copyright (C) 2005-2009 Skomoroh
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# ---------------------------------------------------------------------------
 
 # imports
-import sys
 
 # PySol imports
 from pysollib.gamedb import registerGame, GameInfo, GI
-from pysollib.util import *
-from pysollib.stack import *
 from pysollib.game import Game
 from pysollib.layout import Layout
-from pysollib.hint import AbstractHint, DefaultHint, CautiousDefaultHint
+from pysollib.hint import DefaultHint
 from pysollib.pysoltk import MfxCanvasText
 
+from pysollib.util import ANY_RANK, ANY_SUIT, JACK, KING, NO_RANK, QUEEN, \
+        UNLIMITED_CARDS, UNLIMITED_REDEALS
+
+from pysollib.stack import \
+        AbstractFoundationStack, \
+        BasicRowStack, \
+        DealReserveRedealTalonStack, \
+        DealRowTalonStack, \
+        FaceUpWasteTalonStack, \
+        InitialDealTalonStack, \
+        OpenStack, \
+        Stack, \
+        StackWrapper, \
+        TalonStack, \
+        WasteStack, \
+        WasteTalonStack, \
+        getNumberOfFreeStacks, \
+        ReserveStack
+
 
 # ************************************************************************
 # *
@@ -73,7 +87,8 @@ class Pyramid_StackMethods:
     def _dropPairMove(self, n, other_stack, frames=-1, shadow=-1):
         if not self.game.demo:
             self.game.playSample("droppair", priority=200)
-        assert n == 1 and self.acceptsCards(other_stack, [other_stack.cards[-1]])
+        assert n == 1 and self.acceptsCards(
+            other_stack, [other_stack.cards[-1]])
         old_state = self.game.enterState(self.game.S_FILL)
         f = self.game.s.foundations[0]
         self.game.moveMove(n, self, f, frames=frames, shadow=shadow)
@@ -84,7 +99,8 @@ class Pyramid_StackMethods:
 
     def moveMove(self, ncards, to_stack, frames=-1, shadow=-1):
         if to_stack in self.game.s.foundations:
-            self.game.moveMove(ncards, self, to_stack, frames=frames, shadow=shadow)
+            self.game.moveMove(
+                ncards, self, to_stack, frames=frames, shadow=shadow)
             self.fillStack()
         else:
             self._dropPairMove(ncards, to_stack, frames=-1, shadow=shadow)
@@ -109,6 +125,12 @@ class Pyramid_Talon(Pyramid_StackMethods, FaceUpWasteTalonStack):
             return 1
         return FaceUpWasteTalonStack.clickHandler(self, event)
 
+    def releaseHandler(self, event, drag, sound=True):
+        if self.game.app.opt.mouse_type == 'point-n-click':
+            drag.stack.dragMove(drag, self, sound=sound)
+            return
+        FaceUpWasteTalonStack.releaseHandler(self, event, drag, sound)
+
     def canDealCards(self):
         if not FaceUpWasteTalonStack.canDealCards(self):
             return False
@@ -175,8 +197,8 @@ class Pyramid(Game):
         rows = []
         # create stacks
         for i in range(size):
-            x = x0 + (size-1-i) * l.XS / 2
-            y = y0 + i * l.YS / self.PYRAMID_Y_FACTOR
+            x = x0 + (size-1-i) * l.XS // 2
+            y = y0 + i * l.YS // self.PYRAMID_Y_FACTOR
             for j in range(i+1):
                 stack = self.RowStack_Class(x, y, self)
                 rows.append(stack)
@@ -186,7 +208,7 @@ class Pyramid(Game):
         for i in range(size-1):
             for j in range(i+1):
                 k = n+i+1
-                rows[n].blockmap = [rows[k],rows[k+1]]
+                rows[n].blockmap = [rows[k], rows[k+1]]
                 n += 1
         return rows
 
@@ -194,8 +216,8 @@ class Pyramid(Game):
         rows = []
         # create stacks
         for i in range(size):
-            x = x0 + i * l.XS / 2
-            y = y0 + i * l.YS / self.PYRAMID_Y_FACTOR
+            x = x0 + i * l.XS // 2
+            y = y0 + i * l.YS // self.PYRAMID_Y_FACTOR
             for j in range(size-i):
                 stack = self.RowStack_Class(x, y, self)
                 rows.append(stack)
@@ -210,11 +232,10 @@ class Pyramid(Game):
                 elif j == size-i-1:     # right
                     rows[n].blockmap = [rows[k-1]]
                 else:
-                    rows[n].blockmap = [rows[k-1],rows[k]]
+                    rows[n].blockmap = [rows[k-1], rows[k]]
                 n += 1
         return rows
 
-
     def createGame(self, pyramid_len=7, reserves=0, waste=True, texts=True):
         # create layout
         l, s = Layout(self), self.s
@@ -222,7 +243,7 @@ class Pyramid(Game):
         # set window
         max_rows = max(pyramid_len+2, reserves)
         w = l.XM + max_rows*l.XS
-        h = l.YM + l.YS + (pyramid_len-1)*l.YS/self.PYRAMID_Y_FACTOR
+        h = l.YM + l.YS + (pyramid_len-1)*l.YS//self.PYRAMID_Y_FACTOR
         if reserves:
             h += l.YS+2*l.YOFFSET
         self.setSize(w, h)
@@ -249,7 +270,7 @@ class Pyramid(Game):
                              max_move=0, max_cards=52*decks))
         l.createText(s.foundations[0], 's')
         if reserves:
-            x, y = l.XM+(max_rows-reserves)*l.XS/2, l.YM+4*l.YS
+            x, y = l.XM+(max_rows-reserves)*l.XS//2, l.YM+4*l.YS
             for i in range(reserves):
                 stack = self.Reserve_Class(x, y, self)
                 s.reserves.append(stack)
@@ -263,7 +284,6 @@ class Pyramid(Game):
         if s.waste:
             self.sg.openstacks.append(s.waste)
 
-
     #
     # game overrides
     #
@@ -336,8 +356,8 @@ class Thirteen(Pyramid):
 
         # create stacks
         for i in range(7):
-            x = l.XM + (6-i) * l.XS / 2
-            y = l.YM + l.YS + i * l.YS / 2
+            x = l.XM + (6-i) * l.XS // 2
+            y = l.YM + l.YS + i * l.YS // 2
             for j in range(i+1):
                 s.rows.append(Pyramid_RowStack(x, y, self))
                 x = x + l.XS
@@ -358,7 +378,6 @@ class Thirteen(Pyramid):
         self.sg.openstacks = s.rows + self.sg.talonstacks
         self.sg.dropstacks = s.rows + self.sg.talonstacks
 
-
     #
     # game overrides
     #
@@ -404,8 +423,7 @@ class Thirteens(Pyramid):
         l.defaultStackGroups()
 
     def startGame(self):
-        self.startDealSample()
-        self.s.talon.dealRow()
+        self._startAndDealRow()
 
     def fillStack(self, stack):
         if stack in self.s.rows:
@@ -420,17 +438,18 @@ class Thirteens(Pyramid):
 # * Suit Elevens
 # ************************************************************************
 
+
 class Elevens_RowStack(Giza_Reserve):
     ACCEPTED_SUM = 9
 
     def acceptsCards(self, from_stack, cards):
-        #if self.basicIsBlocked():
+        # if self.basicIsBlocked():
         #    return False
         if from_stack is self or not self.cards or len(cards) != 1:
             return False
         c = self.cards[-1]
-        return (c.face_up and cards[0].face_up
-                and cards[0].rank + c.rank == self.ACCEPTED_SUM)
+        return (c.face_up and cards[0].face_up and
+                cards[0].rank + c.rank == self.ACCEPTED_SUM)
 
     def clickHandler(self, event):
         return OpenStack.clickHandler(self, event)
@@ -451,7 +470,7 @@ class Elevens_Reserve(ReserveStack):
         if not ReserveStack.acceptsCards(self, from_stack, cards):
             return False
         c = cards[0]
-        if not c.rank in self.ACCEPTED_CARDS:
+        if c.rank not in self.ACCEPTED_CARDS:
             return False
         for s in self.game.s.reserves:
             if s.cards and s.cards[0].rank == c.rank:
@@ -489,7 +508,7 @@ class Elevens(Pyramid):
         for i in range(reserves):
             stack = self.Reserve_Class(x, y, self)
             s.reserves.append(stack)
-            stack.CARD_XOFFSET = l.XOFFSET # for fifteens
+            stack.CARD_XOFFSET = l.XOFFSET  # for fifteens
             x += l.XS
 
         if texts:
@@ -501,11 +520,8 @@ class Elevens(Pyramid):
 
         l.defaultStackGroups()
 
-
     def startGame(self):
-        self.startDealSample()
-        self.s.talon.dealRow()
-
+        self._startAndDealRow()
 
     def fillStack(self, stack):
         old_state = self.enterState(self.S_FILL)
@@ -524,7 +540,6 @@ class Elevens(Pyramid):
                 s.moveMove(1, self.s.foundations[0], frames=4)
         self.leaveState(old_state)
 
-
     def shallHighlightMatch(self, stack1, card1, stack2, card2):
         # FIXME
         return False
@@ -558,6 +573,7 @@ class SuitElevens_RowStack(Elevens_RowStack):
             return False
         return cards[0].suit == self.cards[0].suit
 
+
 class SuitElevens_Reserve(Elevens_Reserve):
     def acceptsCards(self, from_stack, cards):
         if not Elevens_Reserve.acceptsCards(self, from_stack, cards):
@@ -567,9 +583,11 @@ class SuitElevens_Reserve(Elevens_Reserve):
                 return False
         return True
 
+
 class SuitElevens(Elevens):
     RowStack_Class = SuitElevens_RowStack
     Reserve_Class = SuitElevens_Reserve
+
     def createGame(self):
         Elevens.createGame(self, rows=3, cols=5)
 
@@ -580,6 +598,7 @@ class SuitElevens(Elevens):
 
 class Fifteens_RowStack(Elevens_RowStack):
     ACCEPTED_SUM = 13
+
     def acceptsCards(self, from_stack, cards):
         if not Elevens_RowStack.acceptsCards(self, from_stack, cards):
             return False
@@ -630,8 +649,8 @@ class Fifteens(Elevens):
         else:
             reserve_ranks = [c.rank for c in reserve.cards]
             reserve_ranks.sort()
-            if (9 in reserve_ranks or JACK in reserve_ranks
-                or QUEEN in reserve_ranks or KING in reserve_ranks):
+            if (9 in reserve_ranks or JACK in reserve_ranks or
+                    QUEEN in reserve_ranks or KING in reserve_ranks):
                 if reserve_ranks == [9, JACK, QUEEN, KING]:
                     self._dropReserve()
             else:
@@ -660,9 +679,9 @@ class TripleAlliance_Reserve(ReserveStack):
         if len(r_ranks) == 2:
             return r_ranks[1]-r_ranks[0] in (1, 12)
         for i in range(3):
-            j, k = (i+1)%3, (i+2)%3
+            j, k = (i+1) % 3, (i+2) % 3
             if ((r_ranks[i]+1) % 13 == r_ranks[j] and
-                (r_ranks[j]+1) % 13 == r_ranks[k]):
+                    (r_ranks[j]+1) % 13 == r_ranks[k]):
                 return True
         return False
 
@@ -703,9 +722,7 @@ class TripleAlliance(Game):
         l.defaultStackGroups()
 
     def startGame(self):
-        self.s.talon.dealRow(frames=0)
-        self.s.talon.dealRow(frames=0)
-        self.startDealSample()
+        self._startDealNumRows(2)
         self.s.talon.dealRowAvail()
 
     def fillStack(self, stack):
@@ -762,12 +779,10 @@ class Pharaohs(Pyramid):
         # define stack-groups
         l.defaultStackGroups()
 
-
     def startGame(self):
         self.startDealSample()
         self.s.talon.dealRow(frames=4)
 
-
     def shallHighlightMatch(self, stack1, card1, stack2, card2):
         return (card1.rank + card2.rank == 11 or
                 card1.rank == card2.rank)
@@ -834,8 +849,7 @@ class Baroness(Pyramid):
         l.defaultStackGroups()
 
     def startGame(self):
-        self.startDealSample()
-        self.s.talon.dealRow()
+        self._startAndDealRow()
 
 
 # ************************************************************************
@@ -849,7 +863,7 @@ class Apophis_Hint(Pyramid_Hint):
             return
         reserves = self.game.s.reserves
         for i in range(3):
-            for j in range(i+1,3):
+            for j in range(i+1, 3):
                 r1 = reserves[i]
                 r2 = reserves[j]
                 if r1.cards and r2.acceptsCards(r1, r1.cards[-1:]):
@@ -917,6 +931,7 @@ class Apophis(Pharaohs):
 # * Cheops
 # ************************************************************************
 
+
 class Cheops_StackMethods(Pyramid_StackMethods):
     def acceptsCards(self, from_stack, cards):
         if self.basicIsBlocked():
@@ -925,16 +940,19 @@ class Cheops_StackMethods(Pyramid_StackMethods):
             return False
         c = self.cards[-1]
         return (c.face_up and cards[0].face_up and
-                abs(cards[0].rank-c.rank) in (0,1))
+                abs(cards[0].rank-c.rank) in (0, 1))
+
 
 class Cheops_Talon(Cheops_StackMethods, Pyramid_Talon):
     def clickHandler(self, event):
         return FaceUpWasteTalonStack.clickHandler(self, event)
 
+
 class Cheops_Waste(Cheops_StackMethods, Pyramid_Waste):
     def clickHandler(self, event):
         return WasteStack.clickHandler(self, event)
 
+
 class Cheops_RowStack(Cheops_StackMethods, Pyramid_RowStack):
     def clickHandler(self, event):
         return OpenStack.clickHandler(self, event)
@@ -948,7 +966,7 @@ class Cheops(Pyramid):
     WasteStack_Class = Cheops_Waste
 
     def shallHighlightMatch(self, stack1, card1, stack2, card2):
-        return abs(card1.rank-card2.rank) in (0,1)
+        return abs(card1.rank-card2.rank) in (0, 1)
 
 
 # ************************************************************************
@@ -957,13 +975,13 @@ class Cheops(Pyramid):
 
 class Exit_RowStack(Elevens_RowStack):
     def acceptsCards(self, from_stack, cards):
-        #if self.basicIsBlocked():
+        # if self.basicIsBlocked():
         #    return False
         if from_stack is self or not self.cards or len(cards) != 1:
             return False
         c1 = self.cards[-1]
         c2 = cards[0]
-        #if not c1.face_up or not c2.face_up:
+        # if not c1.face_up or not c2.face_up:
         #    return False
         return self.game._checkPair(c1, c2)
 
@@ -1028,7 +1046,7 @@ class Exit(Game):
                 swap_index = jack_indexes[1]
             if len(jack_indexes) >= 2:
                 break
-        if not swap_index is None:
+        if swap_index is not None:
             i = -1
             if cards[-1].rank == JACK:  # paranoia
                 i = -2
@@ -1044,8 +1062,8 @@ class Exit(Game):
         self.s.talon.dealRow(rows=self.s.reserves, frames=4)
         self.s.talon.dealRow(rows=self.s.reserves, frames=4)
 
-##     def getAutoStacks(self, event=None):
-##         return ((), (), self.sg.dropstacks)
+        #     def getAutoStacks(self, event=None):
+        #         return ((), (), self.sg.dropstacks)
 
     def shallHighlightMatch(self, stack1, card1, stack2, card2):
         return self._checkPair(card1, card2)
@@ -1105,11 +1123,12 @@ class KingTut(RelaxedPyramid):
         h = l.YM + 5.5*l.YS
         self.setSize(w, h)
 
-        x, y = l.XM+(w-7*l.XS)/2, l.YM
+        x, y = l.XM+(w-7*l.XS)//2, l.YM
         s.rows = self._createPyramid(l, x, y, 7)
 
         x, y = l.XM, self.height-l.YS
-        s.talon = WasteTalonStack(x, y, self, max_rounds=UNLIMITED_REDEALS, num_deal=3)
+        s.talon = WasteTalonStack(
+            x, y, self, max_rounds=UNLIMITED_REDEALS, num_deal=3)
         l.createText(s.talon, "n")
         x += l.XS
         s.waste = Pyramid_Waste(x, y, self, max_accept=1)
@@ -1190,7 +1209,7 @@ class UpAndDown(Pyramid):
         self.setSize(w, h)
 
         # create stacks
-        x, y = l.XM+l.XS/2, l.YM
+        x, y = l.XM+l.XS//2, l.YM
         s.rows = self._createPyramid(l, x, y, 7)
         x += 5.5*l.XS
         s.rows += self._createInvertedPyramid(l, x, y, 7)
@@ -1215,7 +1234,6 @@ class UpAndDown(Pyramid):
         self.sg.dropstacks.append(s.talon)
         self.sg.openstacks.append(s.waste)
 
-
     def startGame(self):
         self.startDealSample()
         self.s.talon.dealRow(frames=4)
@@ -1254,9 +1272,11 @@ class Hurricane_StackMethods(Pyramid_StackMethods):
                                frames=frames, shadow=shadow)
             self.fillStack()
 
+
 class Hurricane_RowStack(Hurricane_StackMethods, BasicRowStack):
     pass
 
+
 class Hurricane_Reserve(Hurricane_StackMethods, OpenStack):
     pass
 
@@ -1269,23 +1289,23 @@ class Hurricane(Pyramid):
         l, s = Layout(self), self.s
 
         # set window
-        ww = l.XS + max(2*l.XOFFSET, l.XS/2)
+        ww = l.XS + max(2*l.XOFFSET, l.XS//2)
         w = l.XM + 1.5*l.XS + 4*ww
         h = l.YM + 3*l.YS
         self.setSize(w, h)
 
         # create stacks
-        for xx, yy in ((0,0),(1,0),(2,0),(3,0),
-                       (0,1),            (3,1),
-                       (0,2),(1,2),(2,2),(3,2),
-                       ):
+        for xx,  yy in ((0, 0), (1, 0), (2, 0), (3, 0),
+                        (0, 1),             (3, 1),
+                        (0, 2), (1, 2), (2, 2), (3, 2),
+                        ):
             x, y = l.XM + 1.5*l.XS + ww*xx, l.YM + l.YS*yy
             stack = Hurricane_Reserve(x, y, self, max_accept=1)
             stack.CARD_XOFFSET, stack.CARD_YOFFSET = l.XOFFSET, 0
             s.reserves.append(stack)
 
         d = 3*ww - 4*l.XS - 2*l.XOFFSET
-        x = l.XM + 1.5*l.XS + l.XS+2*l.XOFFSET + d/2
+        x = l.XM + 1.5*l.XS + l.XS+2*l.XOFFSET + d//2
         y = l.YM+l.YS
         for i in range(3):
             stack = Hurricane_RowStack(x, y, self, max_accept=1)
@@ -1304,7 +1324,6 @@ class Hurricane(Pyramid):
         # define stack-groups
         l.defaultStackGroups()
 
-
     def startGame(self):
         for i in range(2):
             self.s.talon.dealRow(rows=self.s.reserves, frames=0)
@@ -1312,7 +1331,6 @@ class Hurricane(Pyramid):
         self.s.talon.dealRow(rows=self.s.reserves)
         self.s.talon.dealRow()
 
-
     def fillStack(self, stack):
         if stack in self.s.rows and not stack.cards and self.s.talon.cards:
             old_state = self.enterState(self.S_FILL)
@@ -1321,15 +1339,15 @@ class Hurricane(Pyramid):
             self.leaveState(old_state)
 
 
-
 # register the game
 registerGame(GameInfo(38, Pyramid, "Pyramid",
                       GI.GT_PAIRING_TYPE, 1, 2, GI.SL_MOSTLY_LUCK))
 registerGame(GameInfo(193, RelaxedPyramid, "Relaxed Pyramid",
-                      GI.GT_PAIRING_TYPE | GI.GT_RELAXED, 1, 2, GI.SL_MOSTLY_LUCK,
-                      altnames=(" Pyramid's Stones",) ))
-##registerGame(GameInfo(44, Thirteen, "Thirteen",
-##                      GI.GT_PAIRING_TYPE, 1, 0))
+                      GI.GT_PAIRING_TYPE | GI.GT_RELAXED, 1, 2,
+                      GI.SL_MOSTLY_LUCK,
+                      altnames=(" Pyramid's Stones",)))
+# registerGame(GameInfo(44, Thirteen, "Thirteen",
+#                       GI.GT_PAIRING_TYPE, 1, 0))
 registerGame(GameInfo(592, Giza, "Giza",
                       GI.GT_PAIRING_TYPE | GI.GT_OPEN, 1, 0, GI.SL_BALANCED))
 registerGame(GameInfo(593, Thirteens, "Thirteens",
@@ -1348,7 +1366,7 @@ registerGame(GameInfo(655, Pharaohs, "Pharaohs",
                       GI.GT_PAIRING_TYPE, 1, 0, GI.SL_BALANCED))
 registerGame(GameInfo(657, Baroness, "Baroness",
                       GI.GT_PAIRING_TYPE, 1, 0, GI.SL_BALANCED,
-                      altnames=('Five Piles',) ))
+                      altnames=('Five Piles',)))
 registerGame(GameInfo(658, Apophis, "Apophis",
                       GI.GT_PAIRING_TYPE, 1, 2, GI.SL_MOSTLY_LUCK))
 registerGame(GameInfo(659, Cheops, "Cheops",
@@ -1356,7 +1374,8 @@ registerGame(GameInfo(659, Cheops, "Cheops",
 registerGame(GameInfo(674, Exit, "Exit",
                       GI.GT_PAIRING_TYPE, 1, 0, GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(677, TwoPyramids, "Two Pyramids",
-                      GI.GT_PAIRING_TYPE | GI.GT_ORIGINAL, 2, 2, GI.SL_MOSTLY_LUCK))
+                      GI.GT_PAIRING_TYPE | GI.GT_ORIGINAL, 2, 2,
+                      GI.SL_MOSTLY_LUCK))
 registerGame(GameInfo(681, KingTut, "King Tut",
                       GI.GT_PAIRING_TYPE, 1, -1, GI.SL_MOSTLY_LUCK))
 registerGame(GameInfo(699, DoublePyramid, "Double Pyramid",
@@ -1364,6 +1383,7 @@ registerGame(GameInfo(699, DoublePyramid, "Double Pyramid",
 registerGame(GameInfo(700, Triangle, "Triangle",
                       GI.GT_PAIRING_TYPE, 1, 2, GI.SL_MOSTLY_LUCK))
 registerGame(GameInfo(701, UpAndDown, "Up and Down",
-                      GI.GT_PAIRING_TYPE | GI.GT_ORIGINAL, 2, 2, GI.SL_MOSTLY_LUCK))
+                      GI.GT_PAIRING_TYPE | GI.GT_ORIGINAL, 2, 2,
+                      GI.SL_MOSTLY_LUCK))
 registerGame(GameInfo(735, Hurricane, "Hurricane",
                       GI.GT_PAIRING_TYPE, 1, 0, GI.SL_MOSTLY_LUCK))
