@@ -1,40 +1,59 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python
 # -*- mode: python; coding: utf-8; -*-
-##---------------------------------------------------------------------------##
-##
-## Copyright (C) 1998-2003 Markus Franz Xaver Johannes Oberhumer
-## Copyright (C) 2003 Mt. Hood Playing Card Co.
-## Copyright (C) 2005-2009 Skomoroh
-##
-## This program is free software: you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation, either version 3 of the License, or
-## (at your option) any later version.
-##
-## This program is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
-##
-## You should have received a copy of the GNU General Public License
-## along with this program.  If not, see <http://www.gnu.org/licenses/>.
-##
-##---------------------------------------------------------------------------##
-
-__all__ = []
+# ---------------------------------------------------------------------------
+#
+# Copyright (C) 1998-2003 Markus Franz Xaver Johannes Oberhumer
+# Copyright (C) 2003 Mt. Hood Playing Card Co.
+# Copyright (C) 2005-2009 Skomoroh
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# ---------------------------------------------------------------------------
 
 # imports
-import sys
 
 # PySol imports
 from pysollib.gamedb import registerGame, GameInfo, GI
-from pysollib.util import *
-from pysollib.mfxutil import kwdefault
-from pysollib.stack import *
 from pysollib.game import Game
 from pysollib.layout import Layout
-from pysollib.hint import AbstractHint, DefaultHint, CautiousDefaultHint
-from pysollib.pysoltk import MfxCanvasText
+from pysollib.hint import CautiousDefaultHint
+
+from pysollib.util import ACE, ANY_SUIT, JACK, KING, NO_RANK, QUEEN, \
+        UNLIMITED_REDEALS
+
+from pysollib.stack import \
+        AC_FoundationStack, \
+        AbstractFoundationStack, \
+        BasicRowStack, \
+        DealRowRedealTalonStack, \
+        DealRowTalonStack, \
+        InitialDealTalonStack, \
+        KingAC_RowStack, \
+        OpenStack, \
+        RK_FoundationStack, \
+        RK_RowStack, \
+        ReserveStack, \
+        SS_RowStack, \
+        Stack, \
+        StackWrapper, \
+        TalonStack, \
+        UD_AC_RowStack, \
+        UD_SS_RowStack, \
+        WasteStack, \
+        WasteTalonStack, \
+        SS_FoundationStack
+
 
 # ************************************************************************
 # * Sultan
@@ -55,29 +74,30 @@ class Sultan(Game):
         self.setSize(w, h)
 
         # create stacks
-        lay = ((0,0,0,1,13),
-               (2,0,0,1,13),
-               (0,1,1,1,13),
-               (2,1,1,1,13),
-               (1,1,2,0,1),
-               (1,2,2,1,13),
-               (0,2,3,1,13),
-               (2,2,3,1,13),
-               (1,0,2,1,12),
+        lay = ((0, 0, 0, 1, 13),
+               (2, 0, 0, 1, 13),
+               (0, 1, 1, 1, 13),
+               (2, 1, 1, 1, 13),
+               (1, 1, 2, 0, 1),
+               (1, 2, 2, 1, 13),
+               (0, 2, 3, 1, 13),
+               (2, 2, 3, 1, 13),
+               (1, 0, 2, 1, 12),
                )
         for i, j, suit, max_accept, max_cards in lay:
             x, y = 2*l.XM+l.XS+i*l.XS, l.YM+j*l.YS
-            stack = SS_FoundationStack(x, y, self, suit=suit,
-                    max_move=0, max_accept=max_accept, max_cards=max_cards, mod=13)
+            stack = SS_FoundationStack(
+                x, y, self, suit=suit,
+                max_move=0, max_accept=max_accept, max_cards=max_cards, mod=13)
             s.foundations.append(stack)
 
         x, y = l.XM, l.YM
-        for i in range(reserves/2):
+        for i in range(reserves//2):
             s.rows.append(ReserveStack(x, y, self))
             y += l.YS
 
         x, y = 3*l.XM+4*l.XS, l.YM
-        for i in range(reserves/2):
+        for i in range(reserves//2):
             s.rows.append(ReserveStack(x, y, self))
             y += l.YS
 
@@ -97,17 +117,17 @@ class Sultan(Game):
     #
 
     def _shuffleHook(self, cards):
-        cards = self._shuffleHookMoveToTop(cards,
-                    lambda c: (c.rank == ACE and c.suit == 2 and c.deck == 0, c.suit))
-        cards = self._shuffleHookMoveToTop(cards,
-                    lambda c: (c.rank == KING, c.suit))
+        cards = self._shuffleHookMoveToTop(
+            cards,
+            lambda c: (c.rank == ACE and c.suit == 2 and c.deck == 0, c.suit))
+        cards = self._shuffleHookMoveToTop(
+            cards,
+            lambda c: (c.rank == KING, c.suit))
         return cards
 
     def startGame(self):
         self.s.talon.dealRow(rows=self.s.foundations, frames=0)
-        self.startDealSample()
-        self.s.talon.dealRow()
-        self.s.talon.dealCards()          # deal first card to WasteStack
+        self._startAndDealRowAndCards()
 
     def getAutoStacks(self, event=None):
         return (self.sg.dropstacks, (), self.sg.dropstacks)
@@ -116,7 +136,7 @@ class Sultan(Game):
 class SultanPlus(Sultan):
     def createGame(self):
         Sultan.createGame(self, reserves=8)
- 
+
 
 # ************************************************************************
 # * Boudoir
@@ -168,8 +188,9 @@ class Boudoir(Game):
 
     def _shuffleHook(self, cards):
         # move 4 Queens to top of the Talon (i.e. first cards to be dealt)
-        return self._shuffleHookMoveToTop(cards,
-                   lambda c: (c.rank == QUEEN and c.deck == 0, c.suit))
+        return self._shuffleHookMoveToTop(
+            cards,
+            lambda c: (c.rank == QUEEN and c.deck == 0, c.suit))
 
     def startGame(self):
         self.startDealSample()
@@ -191,7 +212,7 @@ class CaptiveQueens(Game):
         l, s = Layout(self), self.s
         self.setSize(l.XM+5.5*l.XS, l.YM+3*l.YS)
 
-        x, y = l.XM, l.YM+l.YS/2
+        x, y = l.XM, l.YM+l.YS//2
         s.talon = WasteTalonStack(x, y, self, max_rounds=3)
         l.createText(s.talon, "se")
         l.createRoundText(s.talon, 'nn')
@@ -240,12 +261,12 @@ class Contradance(Game):
 
         x, y = l.XM, l.YM
         for i in range(8):
-            s.foundations.append(SS_FoundationStack(x, y, self, suit=i/2,
+            s.foundations.append(SS_FoundationStack(x, y, self, suit=i//2,
                                  base_rank=4, dir=-1, mod=13, max_cards=6))
             x += l.XS
         x, y = l.XM, l.YM+l.YS
         for i in range(8):
-            s.foundations.append(SS_FoundationStack(x, y, self, suit=i/2,
+            s.foundations.append(SS_FoundationStack(x, y, self, suit=i//2,
                                  base_rank=5, max_cards=7))
             x += l.XS
 
@@ -259,12 +280,11 @@ class Contradance(Game):
 
         l.defaultStackGroups()
 
-
     def _shuffleHook(self, cards):
         # move 5's and 6's to top of the Talon (i.e. first cards to be dealt)
-        return self._shuffleHookMoveToTop(cards,
-                   lambda c: (c.rank in (4, 5), (c.rank, c.suit)))
-
+        return self._shuffleHookMoveToTop(
+            cards,
+            lambda c: (c.rank in (4, 5), (c.rank, c.suit)))
 
     def startGame(self):
         self.startDealSample()
@@ -300,16 +320,20 @@ class IdleAces(Game):
         k = 0
         for i, j in((2, 0), (0, 1.5), (4, 1.5), (2, 3)):
             x, y = x0+i*l.XS, y0+j*l.YS
-            s.foundations.append(RK_FoundationStack(x, y, self,
-                                 ##suit=ANY_SUIT,
-                                 base_rank=KING, dir=-1, max_move=0))
+            s.foundations.append(
+                RK_FoundationStack(
+                    x, y, self,
+                    # suit=ANY_SUIT,
+                    base_rank=KING, dir=-1, max_move=0))
             k += 1
         k = 0
         for i, j in((2, 1), (1, 1.5), (3, 1.5), (2, 2)):
             x, y = x0+i*l.XS, y0+j*l.YS
-            s.foundations.append(RK_FoundationStack(x, y, self,
-                                 ##suit=ANY_SUIT,
-                                 base_rank=1, max_move=0, max_cards=12))
+            s.foundations.append(
+                RK_FoundationStack(
+                    x, y, self,
+                    # suit=ANY_SUIT,
+                    base_rank=1, max_move=0, max_cards=12))
             k += 1
         k = 0
         for i, j in((1, 0.2), (3, 0.2), (1, 2.8), (3, 2.8)):
@@ -320,11 +344,10 @@ class IdleAces(Game):
 
         l.defaultStackGroups()
 
-
     def _shuffleHook(self, cards):
-        return self._shuffleHookMoveToTop(cards,
-                   lambda c: (c.rank in (1, KING) and c.deck == 0, (-c.rank, c.suit)))
-
+        return self._shuffleHookMoveToTop(
+            cards,
+            lambda c: (c.rank in (1, KING) and c.deck == 0, (-c.rank, c.suit)))
 
     def startGame(self):
         self.startDealSample()
@@ -357,34 +380,38 @@ class LadyOfTheManor(Game):
         x, y = l.XM, self.height-l.YS
         for i in range(4):
             suit = i
-            if self.Foundation_Class_1 is RK_FoundationStack: suit = ANY_SUIT
-            s.foundations.append(self.Foundation_Class_1(x, y, self, suit=suit))
+            if self.Foundation_Class_1 is RK_FoundationStack:
+                suit = ANY_SUIT
+            s.foundations.append(
+                self.Foundation_Class_1(x, y, self, suit=suit))
             x += l.XS
         for i in range(4):
             suit = i
-            if self.Foundation_Class_1 is RK_FoundationStack: suit = ANY_SUIT
-            s.foundations.append(self.Foundation_Class_2(x, y, self, suit=suit))
+            if self.Foundation_Class_1 is RK_FoundationStack:
+                suit = ANY_SUIT
+            s.foundations.append(
+                self.Foundation_Class_2(x, y, self, suit=suit))
             x += l.XS
         x, y = l.XM+2*l.XS, l.YM+l.YS
         for i in range(4):
             s.rows.append(LadyOfTheManor_RowStack(x, y, self, max_accept=0))
             x += l.XS
-        for i, j in ((0,2), (0,1), (0,0),
-                     (1,0), (2,0), (3,0), (4,0), (5,0), (6,0),
-                     (7,0), (7,1), (7,2),):
+        for i, j in ((0, 2), (0, 1), (0, 0),
+                     (1, 0), (2, 0), (3, 0), (4, 0), (5, 0), (6, 0),
+                     (7, 0), (7, 1), (7, 2), ):
             x, y = l.XM+i*l.XS, l.YM+j*l.YS
             s.reserves.append(LadyOfTheManor_Reserve(x, y, self, max_accept=0))
 
-        s.talon = InitialDealTalonStack(self.width-l.XS, self.height-2*l.YS, self)
+        s.talon = InitialDealTalonStack(
+            self.width-l.XS, self.height-2*l.YS, self)
 
         l.defaultAll()
 
-
     def _shuffleHook(self, cards):
         # move Aces to top of the Talon (i.e. first cards to be dealt)
-        return self._shuffleHookMoveToTop(cards,
-                   lambda c: (c.rank == ACE, c.suit))
-
+        return self._shuffleHookMoveToTop(
+            cards,
+            lambda c: (c.rank == ACE, c.suit))
 
     def startGame(self, flip=False):
         self.s.talon.dealRow(rows=self.s.foundations, frames=0)
@@ -411,10 +438,8 @@ class Matrimony_Talon(DealRowTalonStack):
         return not self.game.isGameWon()
 
     def _redeal(self):
-        lr = len(self.game.s.rows)
         num_cards = 0
         assert len(self.cards) == 0
-        rows = self.game.s.rows
         r = self.game.s.rows[-self.round]
         for i in range(len(r.cards)):
             num_cards += 1
@@ -436,7 +461,8 @@ class Matrimony_Talon(DealRowTalonStack):
             rows = self.game.s.rows[-self.round+1:]
             num_cards += self.dealRowAvail(rows=rows, sound=False)
             while self.cards:
-                num_cards += self.dealRowAvail(rows=self.game.s.rows, sound=False)
+                num_cards += self.dealRowAvail(
+                    rows=self.game.s.rows, sound=False)
         if sound:
             self.game.stopSamples()
         return num_cards
@@ -475,18 +501,16 @@ class Matrimony(Game):
 
         l.defaultStackGroups()
 
-
     def _shuffleHook(self, cards):
-        return self._shuffleHookMoveToTop(cards,
+        return self._shuffleHookMoveToTop(
+            cards,
             lambda c: (c.rank in (JACK, QUEEN) and c.deck == 0 and c.suit == 3,
                        (c.rank, c.suit)))
 
-
     def startGame(self):
         self.s.talon.dealRow(rows=[self.s.foundations[3],
                                    self.s.foundations[7]], frames=0)
-        self.startDealSample()
-        self.s.talon.dealRow()
+        self._startAndDealRow()
 
 
 # ************************************************************************
@@ -521,7 +545,7 @@ class PicturePatience(Game):
                                             max_cards=1, max_accept=1))
                 x += l.XS
             y += l.YS
-        x, y = 2*l.XM+l.XS+l.XS/2, l.YM+3*l.YS
+        x, y = 2*l.XM+l.XS+l.XS//2, l.YM+3*l.YS
         s.talon = WasteTalonStack(x, y, self, max_rounds=max_rounds)
         x += l.XS
         s.waste = WasteStack(x, y, self)
@@ -535,13 +559,11 @@ class PicturePatience(Game):
 
         l.defaultStackGroups()
 
-
     def startGame(self):
         self.startDealSample()
         self.s.talon.dealRow()
         self.s.talon.dealCards()
 
-
     def fillStack(self, stack):
         if stack in self.s.rows and not stack.cards:
             if not self.s.waste.cards:
@@ -555,9 +577,10 @@ class Patriarchs(PicturePatience):
         PicturePatience.createGame(self, max_rounds=2)
 
     def _shuffleHook(self, cards):
-        return self._shuffleHookMoveToTop(cards,
-                   lambda c: (c.rank in (ACE, KING) and c.deck == 0,
-                              (c.rank, c.suit)))
+        return self._shuffleHookMoveToTop(
+            cards,
+            lambda c: (c.rank in (ACE, KING) and c.deck == 0,
+                       (c.rank, c.suit)))
 
     def startGame(self):
         self.s.talon.dealRow(rows=self.s.foundations, frames=0)
@@ -609,12 +632,11 @@ class SixesAndSevens(Game):
 
         l.defaultStackGroups()
 
-
     def _shuffleHook(self, cards):
-        return self._shuffleHookMoveToTop(cards,
+        return self._shuffleHookMoveToTop(
+            cards,
             lambda c: (c.rank in (5, 6), (-c.rank, c.deck, c.suit)))
 
-
     def startGame(self):
         self.s.talon.dealRow(rows=self.s.foundations, frames=0)
         self.startDealSample()
@@ -630,7 +652,7 @@ class TwoRings(Game):
         self.setSize(l.XM+10*l.XS, l.YM+5*l.YS)
 
         lay = (
-            (1.5, 0  ),
+            (1.5, 0),
             (2.5, 0.3),
             (3,   1.3),
             (2.5, 2.3),
@@ -644,14 +666,14 @@ class TwoRings(Game):
         x0, y0 = l.XM+l.XS, l.YM
         for xx, yy in lay:
             x, y = x0+xx*l.XS, y0+yy*l.YS
-            s.foundations.append(SS_FoundationStack(x, y, self, suit=suit/2,
+            s.foundations.append(SS_FoundationStack(x, y, self, suit=suit//2,
                                  base_rank=6, max_cards=7))
             suit += 1
         suit = 0
         x0, y0 = l.XM+5*l.XS, l.YM
         for xx, yy in lay:
             x, y = x0+xx*l.XS, y0+yy*l.YS
-            s.foundations.append(SS_FoundationStack(x, y, self, suit=suit/2,
+            s.foundations.append(SS_FoundationStack(x, y, self, suit=suit//2,
                                  base_rank=5, dir=-1, max_cards=6))
             suit += 1
 
@@ -669,16 +691,14 @@ class TwoRings(Game):
 
         l.defaultStackGroups()
 
-
     def _shuffleHook(self, cards):
-        return self._shuffleHookMoveToTop(cards,
+        return self._shuffleHookMoveToTop(
+            cards,
             lambda c: (c.rank in (5, 6), (-c.rank, c.suit)))
 
-
     def startGame(self):
         self.s.talon.dealRow(rows=self.s.foundations, frames=0)
-        self.startDealSample()
-        self.s.talon.dealRow()
+        self._startAndDealRow()
 
 
 # ************************************************************************
@@ -703,12 +723,12 @@ class CornerSuite(Game):
         self.setSize(l.XM+5*l.XS, l.YM+5*l.YS)
 
         suit = 0
-        for x, y in ((0,0), (4,0), (0,4), (4,4)):
+        for x, y in ((0, 0), (4, 0), (0, 4), (4, 4)):
             x, y = l.XM+x*l.XS, l.YM+y*l.YS
             s.foundations.append(SS_FoundationStack(x, y, self, suit=suit))
             suit += 1
 
-        x, y = l.XM+3*l.XS/2, l.YM
+        x, y = l.XM+3*l.XS//2, l.YM
         s.talon = WasteTalonStack(x, y, self, max_rounds=1)
         l.createText(s.talon, 'nw')
         x += l.XS
@@ -761,12 +781,12 @@ class Marshal(Game):
             s.foundations.append(SS_FoundationStack(x, y, self,
                                  suit=i, base_rank=KING, dir=-1))
             y += l.YS
-        x, y = (self.width-l.XS)/2, self.height-l.YS
+        x, y = (self.width-l.XS)//2, self.height-l.YS
         s.talon = DealRowTalonStack(x, y, self)
         l.createText(s.talon, 'se')
         y = l.YM
         for i in range(4):
-            x = l.XM+l.XS*3/2
+            x = l.XM+l.XS*3//2
             for j in range(6):
                 stack = UD_SS_RowStack(x, y, self, base_rank=NO_RANK)
                 s.rows.append(stack)
@@ -777,8 +797,7 @@ class Marshal(Game):
         l.defaultStackGroups()
 
     def startGame(self):
-        self.startDealSample()
-        self.s.talon.dealRow()
+        self._startAndDealRow()
 
     def fillStack(self, stack):
         if stack in self.s.rows and not stack.cards:
@@ -805,9 +824,9 @@ class RoyalAids(Game):
         self.setSize(l.XM+8*l.XS, l.YM+4*l.YS+l.TEXT_HEIGHT)
 
         x0 = l.XM+1.5*l.XS
-        for k in (0,1):
+        for k in (0, 1):
             suit = 0
-            for i, j in ((1,0), (0,0.5), (2,0.5), (1,1)):
+            for i, j in ((1, 0), (0, 0.5), (2, 0.5), (1, 1)):
                 x, y = x0+i*l.XS, l.YM+j*l.YS
                 s.foundations.append(AC_FoundationStack(x, y, self, suit=suit))
                 suit += 1
@@ -821,7 +840,7 @@ class RoyalAids(Game):
         l.createText(s.waste, 'se')
 
         x, y = l.XM+3.75*l.XS, l.YM+2*l.YS
-        for i in (0,1):
+        for i in (0, 1):
             stack = KingAC_RowStack(x, y, self, max_move=1)
             stack.getBottomImage = stack._getReserveBottomImage
             s.rows.append(stack)
@@ -837,11 +856,10 @@ class RoyalAids(Game):
 
         l.defaultStackGroups()
 
-
     def _shuffleHook(self, cards):
-        return self._shuffleHookMoveToTop(cards,
-                   lambda c: (c.rank == ACE, (c.deck, c.suit)))
-
+        return self._shuffleHookMoveToTop(
+            cards,
+            lambda c: (c.rank == ACE, (c.deck, c.suit)))
 
     def startGame(self):
         self.s.talon.dealRow(rows=self.s.foundations, frames=0)
@@ -852,7 +870,6 @@ class RoyalAids(Game):
             self.s.talon.dealRow(rows=self.s.reserves)
         self.s.talon.dealCards()
 
-
     shallHighlightMatch = Game._shallHighlightMatch_AC
 
 
@@ -867,14 +884,14 @@ class CircleEight(Game):
         l, s = Layout(self), self.s
         self.setSize(l.XM+5*l.XS, l.YM+4*l.YS)
 
-        for i, j in ((1,0),
-                     (2,0),
-                     (3,0),
-                     (4,1.5),
-                     (3,3),
-                     (2,3),
-                     (1,3),
-                     (0,1.5),
+        for i, j in ((1, 0),
+                     (2, 0),
+                     (3, 0),
+                     (4, 1.5),
+                     (3, 3),
+                     (2, 3),
+                     (1, 3),
+                     (0, 1.5),
                      ):
             x, y = l.XM+i*l.XS, l.YM+j*l.YS
             stack = RK_RowStack(x, y, self, dir=1, mod=13, max_move=0)
@@ -911,7 +928,7 @@ class Adela_Foundation(SS_FoundationStack):
         if not SS_FoundationStack.acceptsCards(self, from_stack, cards):
             return False
         index = list(self.game.s.foundations).index(self)
-        index = index%8
+        index %= 8
         return len(self.game.s.foundations[index].cards) > 0
 
 
@@ -925,35 +942,33 @@ class Adela(Game):
 
         x, y = l.XM+l.XS, l.YM
         for i in range(8):
-            s.foundations.append(SS_FoundationStack(x, y, self, suit=i%4,
+            s.foundations.append(SS_FoundationStack(x, y, self, suit=i % 4,
                                  base_rank=JACK, dir=-1, max_cards=11))
             x += l.XS
         x, y = l.XM+l.XS, l.YM+l.YS
         for i in range(8):
-            s.foundations.append(Adela_Foundation(x, y, self, suit=i%4,
+            s.foundations.append(Adela_Foundation(x, y, self, suit=i % 4,
                                  base_rank=QUEEN, max_cards=1))
             x += l.XS
         x, y = l.XM+l.XS, l.YM+2*l.YS
         for i in range(8):
-            s.foundations.append(Adela_Foundation(x, y, self, suit=i%4,
+            s.foundations.append(Adela_Foundation(x, y, self, suit=i % 4,
                                  base_rank=KING, max_cards=1))
             x += l.XS
         x, y = l.XM, l.YM+l.YS
         s.talon = DealRowTalonStack(x, y, self)
         l.createText(s.talon, 'n')
-        x, y = l.XM+l.XS/2, l.YM+3*l.YS
+        x, y = l.XM+l.XS//2, l.YM+3*l.YS
         for i in range(9):
             stack = SS_RowStack(x, y, self, max_move=1, dir=1)
             s.rows.append(stack)
             stack.CARD_YOFFSET = 0
             x += l.XS
-            
+
         l.defaultStackGroups()
 
-
     def startGame(self):
-        self.startDealSample()
-        self.s.talon.dealRow()
+        self._startAndDealRow()
 
     def fillStack(self, stack):
         if stack in self.s.rows and not stack.cards:
@@ -979,7 +994,7 @@ class Toni(Game):
 
         y = l.YM
         suit = 0
-        for i in (0,1,3,4):
+        for i in (0, 1, 3, 4):
             x = l.XM+(2+i)*l.XS
             s.foundations.append(SS_FoundationStack(x, y, self, suit=suit))
             suit += 1
@@ -990,8 +1005,8 @@ class Toni(Game):
                                                     base_rank=KING, dir=-1))
             y += l.YS
 
-        for i, j in ((0,0),(1,0),(2,0),(5,0),(6,0),(7,0),
-                     (0,1),(1,1),(2,1),(5,1),(6,1),(7,1),
+        for i, j in ((0, 0), (1, 0), (2, 0), (5, 0), (6, 0), (7, 0),
+                     (0, 1), (1, 1), (2, 1), (5, 1), (6, 1), (7, 1),
                      ):
             x, y = l.XM+(0.5+i)*l.XS, l.YM+(1.5+j)*l.YS
             stack = BasicRowStack(x, y, self, max_accept=0)
@@ -1005,16 +1020,15 @@ class Toni(Game):
 
         l.defaultStackGroups()
 
-
     def _shuffleHook(self, cards):
-        return self._shuffleHookMoveToTop(cards,
-           lambda c: (c.rank in (ACE, KING) and c.deck == 0, (c.rank, c.suit)))
-
+        return self._shuffleHookMoveToTop(
+            cards,
+            lambda c: (c.rank in (ACE, KING) and c.deck == 0,
+                       (c.rank, c.suit)))
 
     def startGame(self):
         self.s.talon.dealRow(rows=self.s.foundations, frames=0)
-        self.startDealSample()
-        self.s.talon.dealRow()
+        self._startAndDealRow()
 
 
 # ************************************************************************
@@ -1035,13 +1049,12 @@ class Khedive(Game):
             x += l.XS
 
         x, y = l.XM+4*l.XS, l.YM
-        r = range(11)
-        for i in range(5,0,-1):
+        r = list(range(11))
+        for i in range(5, 0, -1):
             for j in r[i:-i]:
                 x, y = l.XM+(j-0.5)*l.XS, l.YM+(5-i)*l.YS
                 s.rows.append(BasicRowStack(x, y, self, max_accept=0))
 
-
         x, y = l.XM, l.YM+1.5*l.YS
         s.talon = WasteTalonStack(x, y, self, max_rounds=1)
         l.createText(s.talon, 'ne')
@@ -1079,7 +1092,7 @@ class Phalanx(Game):
 
         y = l.YM
         for i in range(5):
-            x = l.XM+(8-i)*l.XS/2
+            x = l.XM+(8-i)*l.XS//2
             for j in range(i+1):
                 s.rows.append(ReserveStack(x, y, self))
                 x += l.XS
@@ -1103,14 +1116,12 @@ class Phalanx(Game):
 
         l.defaultStackGroups()
 
-
     def startGame(self):
         self.startDealSample()
         self.s.talon.dealRow(frames=4)
         self.s.talon.dealCards()
 
 
-
 # ************************************************************************
 # * Grandee
 # * Turncoats
@@ -1129,11 +1140,11 @@ class Grandee(Game):
 
         # set window
         decks = self.gameinfo.decks
-        w = max(decks*4, rows/2)
+        w = max(decks*4, rows//2)
         self.setSize(l.XM+w*l.XS, l.YM+5*l.YS)
 
         # create stacks
-        x, y = l.XM + (w-decks*4)*l.XS/2, l.YM
+        x, y = l.XM + (w-decks*4)*l.XS//2, l.YM
         for i in range(4):
             for j in range(decks):
                 s.foundations.append(SS_FoundationStack(x, y, self, suit=i))
@@ -1141,8 +1152,8 @@ class Grandee(Game):
 
         y = l.YM+1.5*l.YS
         for i in range(2):
-            x = l.XM + (w-rows/2)*l.XS/2
-            for j in range(rows/2):
+            x = l.XM + (w-rows//2)*l.XS//2
+            for j in range(rows//2):
                 stack = self.RowStack_Class(x, y, self, max_move=1)
                 stack.CARD_YOFFSET = 0
                 s.rows.append(stack)
@@ -1163,8 +1174,7 @@ class Grandee(Game):
         l.defaultStackGroups()
 
     def startGame(self):
-        self.startDealSample()
-        self.s.talon.dealRow()
+        self._startAndDealRow()
 
     shallHighlightMatch = Game._shallHighlightMatch_SS
 
@@ -1228,14 +1238,14 @@ class DesertIsland(Game):
         x, y = l.XM, l.YM
         for i in range(8):
             s.foundations.append(SS_FoundationStack(x, y, self,
-                                                    suit=i/2, max_cards=10))
+                                                    suit=i//2, max_cards=10))
             x += l.XS
 
         y = l.YM+l.YS
         for i in range(3):
             x = l.XM
             for j in range(8):
-                ##stack = SS_RowStack(x, y, self, max_move=1)
+                # stack = SS_RowStack(x, y, self, max_move=1)
                 stack = ReserveStack(x, y, self)
                 stack.CARD_YOFFSET = 0
                 s.rows.append(stack)
@@ -1249,15 +1259,14 @@ class DesertIsland(Game):
         # define stack-groups
         l.defaultStackGroups()
 
-
     def _shuffleHook(self, cards):
-        return self._shuffleHookMoveToTop(cards,
-                   lambda c: (c.rank == ACE, c.suit))
+        return self._shuffleHookMoveToTop(
+            cards,
+            lambda c: (c.rank == ACE, c.suit))
 
     def startGame(self):
         self.s.talon.dealRow(rows=self.s.foundations, frames=0)
-        self.startDealSample()
-        self.s.talon.dealRow()
+        self._startAndDealRow()
 
     def isGameWon(self):
         for s in self.s.foundations:
@@ -1279,14 +1288,14 @@ class CatherineTheGreat(Game):
         w, h = 3*l.XM+5*l.XS, l.YM+5*l.YS
         self.setSize(w, h)
 
-        lay = ((0,2,0,QUEEN,-1),
-               (0,1,0,QUEEN,-1),
-               (0,0,1,QUEEN,-1),
-               (2,0,1,QUEEN,-1),
-               (1,0,2,QUEEN,-1),
-               (2,1,3,QUEEN,-1),
-               (2,2,3,QUEEN,-1),
-               (1,1,2,KING,1),
+        lay = ((0, 2, 0, QUEEN, -1),
+               (0, 1, 0, QUEEN, -1),
+               (0, 0, 1, QUEEN, -1),
+               (2, 0, 1, QUEEN, -1),
+               (1, 0, 2, QUEEN, -1),
+               (2, 1, 3, QUEEN, -1),
+               (2, 2, 3, QUEEN, -1),
+               (1, 1, 2, KING, 1),
                )
         for xx, yy, suit, base_rank, dir in lay:
             x, y = 2*l.XM+l.XS+xx*l.XS, l.YM+yy*l.YS
@@ -1323,14 +1332,13 @@ class CatherineTheGreat(Game):
                     return (False, 0)
                 return (True, card.suit)
             return (False, 0)
-        cards = self._shuffleHookMoveToTop(cards, select_func)
+        cards = self._shuffleHookMoveToTop(
+            cards, select_func)
         return cards
 
     def startGame(self):
         self.s.talon.dealRow(rows=self.s.foundations, frames=0)
-        self.startDealSample()
-        self.s.talon.dealRow()
-        self.s.talon.dealCards()        # deal first card to WasteStack
+        self._startAndDealRowAndCards()
 
     def fillStack(self, stack):
         if stack in self.s.rows and not stack.cards:
@@ -1344,26 +1352,25 @@ class CatherineTheGreat(Game):
     shallHighlightMatch = Game._shallHighlightMatch_RKW
 
 
-
 # register the game
 registerGame(GameInfo(330, Sultan, "Sultan",
                       GI.GT_2DECK_TYPE, 2, 2, GI.SL_MOSTLY_LUCK,
-                      altnames=("Sultan of Turkey",) ))
+                      altnames=("Sultan of Turkey",)))
 registerGame(GameInfo(331, SultanPlus, "Sultan +",
                       GI.GT_2DECK_TYPE, 2, 2, GI.SL_MOSTLY_LUCK))
 registerGame(GameInfo(354, Boudoir, "Boudoir",
                       GI.GT_2DECK_TYPE, 2, 2, GI.SL_MOSTLY_LUCK))
 registerGame(GameInfo(410, CaptiveQueens, "Captive Queens",
                       GI.GT_1DECK_TYPE, 1, 2, GI.SL_MOSTLY_LUCK,
-                      altnames=("Quadrille",) ))
+                      altnames=("Quadrille",)))
 registerGame(GameInfo(418, Contradance, "Contradance",
                       GI.GT_2DECK_TYPE, 2, 1, GI.SL_LUCK,
-                      altnames=("Cotillion",) ))
+                      altnames=("Cotillion",)))
 registerGame(GameInfo(419, IdleAces, "Idle Aces",
                       GI.GT_2DECK_TYPE, 2, 2, GI.SL_MOSTLY_LUCK))
 registerGame(GameInfo(423, LadyOfTheManor, "Lady of the Manor",
                       GI.GT_2DECK_TYPE, 2, 0, GI.SL_MOSTLY_LUCK,
-                      altnames=("Vassal", "La Chatelaine") ))
+                      altnames=("Vassal", "La Chatelaine")))
 registerGame(GameInfo(424, Matrimony, "Matrimony",
                       GI.GT_2DECK_TYPE, 2, 16, GI.SL_MOSTLY_LUCK))
 registerGame(GameInfo(429, Patriarchs, "Patriarchs",
