@@ -1,48 +1,68 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python
 # -*- mode: python; coding: utf-8; -*-
-##---------------------------------------------------------------------------##
-##
-## Copyright (C) 1998-2003 Markus Franz Xaver Johannes Oberhumer
-## Copyright (C) 2003 Mt. Hood Playing Card Co.
-## Copyright (C) 2005-2009 Skomoroh
-##
-## This program is free software: you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation, either version 3 of the License, or
-## (at your option) any later version.
-##
-## This program is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
-##
-## You should have received a copy of the GNU General Public License
-## along with this program.  If not, see <http://www.gnu.org/licenses/>.
-##
-##---------------------------------------------------------------------------##
-
-__all__ = []
+# ---------------------------------------------------------------------------##
+#
+# Copyright (C) 1998-2003 Markus Franz Xaver Johannes Oberhumer
+# Copyright (C) 2003 Mt. Hood Playing Card Co.
+# Copyright (C) 2005-2009 Skomoroh
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# ---------------------------------------------------------------------------##
 
 # Imports
-import sys, math
 
 # PySol imports
+from pysollib.mygettext import _
 from pysollib.gamedb import registerGame, GameInfo, GI
-from pysollib.util import *
 from pysollib.mfxutil import kwdefault
-from pysollib.stack import *
-from pysollib.game import Game
 from pysollib.layout import Layout
 from pysollib.hint import FreeCellType_Hint
 from pysollib.pysoltk import MfxCanvasText
 
-from hanafuda_common import *
+from pysollib.games.ultra.hanafuda_common import \
+        FlowerClock_Foundation, \
+        FlowerClock_RowStack, \
+        FourWinds_Foundation, \
+        FourWinds_RowStack, \
+        Gaji_Foundation, \
+        Gaji_RowStack, \
+        GreatWall_FoundationStack, \
+        GreatWall_RowStack, \
+        Hanafuda_SS_FoundationStack, \
+        Hanafuda_SequenceStack, \
+        MatsuKiri_Foundation, \
+        Matsukiri_RowStack, \
+        Oonsoo_SequenceStack, \
+        Pagoda_Foundation, \
+        AbstractFlowerGame
 
+from pysollib.util import ANY_RANK, ANY_SUIT
+
+from pysollib.stack import \
+        DealRowTalonStack, \
+        InitialDealTalonStack, \
+        ReserveStack, \
+        WasteStack, \
+        cardsFaceUp, \
+        WasteTalonStack
 
 # ************************************************************************
 #  * Flower Clock
 #  ***********************************************************************/
 
+
 class FlowerClock(AbstractFlowerGame):
 
     #
@@ -57,29 +77,33 @@ class FlowerClock(AbstractFlowerGame):
         self.setSize(l.XM + l.XS * 10.5, l.YM + l.YS * 5.5)
 
         # Create clock
-        xoffset = ( 1, 2, 2.5, 2, 1, 0, -1, -2, -2.5, -2, -1, 0 )
-        yoffset = ( 0.25, 0.75, 1.9, 3, 3.5, 3.75, 3.5, 3, 1.9, 0.75, 0.25, 0 )
+        xoffset = (1, 2, 2.5, 2, 1, 0, -1, -2, -2.5, -2, -1, 0)
+        yoffset = (0.25, 0.75, 1.9, 3, 3.5, 3.75, 3.5, 3, 1.9, 0.75, 0.25, 0)
         x = l.XM + l.XS * 7
-        y = l.CH / 3
+        y = l.CH // 3
         for i in range(12):
             x0 = x + xoffset[i] * l.XS
             y0 = y + yoffset[i] * l.YS
-            s.foundations.append(FlowerClock_Foundation(x0, y0, self, ANY_SUIT, base_rank=3))
-            t = MfxCanvasText(self.canvas, x0 + l.CW / 2, y0 + l.YS,
+            stack = FlowerClock_Foundation(x0, y0, self, ANY_SUIT, base_rank=3)
+            s.foundations.append(stack)
+            t = MfxCanvasText(self.canvas, x0 + l.CW // 2, y0 + l.YS,
                               anchor="center", font=font,
                               text=self.SUITS[i])
+            stack.texts.misc = t
 
         # Create row stacks
         for j in range(2):
             x, y = l.XM, l.YM + l.YS * j * 2.7
             for i in range(4):
-                s.rows.append(FlowerClock_RowStack(x, y, self, yoffset=l.CH/4,
+                s.rows.append(FlowerClock_RowStack(x, y, self,
+                                                   yoffset=l.CH//4,
                                                    max_cards=8, max_accept=8))
                 x = x + l.XS
         self.setRegion(s.rows, (0, 0, l.XS * 4, 999999))
 
         # Create talon
-        s.talon = InitialDealTalonStack(self.width - l.XS, self.height - l.YS, self)
+        s.talon = InitialDealTalonStack(
+            self.width - l.XS, self.height - l.YS, self)
 
         # Define stack groups
         l.defaultStackGroups()
@@ -90,9 +114,7 @@ class FlowerClock(AbstractFlowerGame):
 
     def startGame(self):
         assert len(self.s.talon.cards) == 48
-        for i in range(5):
-            self.s.talon.dealRow(frames=0)
-        self.startDealSample()
+        self._startDealNumRows(5)
         self.s.talon.dealRow()
         assert len(self.s.talon.cards) == 0
 
@@ -111,7 +133,6 @@ class FlowerClock(AbstractFlowerGame):
             return (self.sg.dropstacks, self.sg.dropstacks, self.sg.dropstacks)
 
 
-
 # ************************************************************************
 #  * Gaji
 #  ***********************************************************************/
@@ -132,25 +153,27 @@ class Gaji(AbstractFlowerGame):
         x = l.XM
         y = l.YM
         s.foundations.append(Gaji_Foundation(x, y, self, -1, base_rank=0))
-        x = x + l.XS
+        x += l.XS
         s.foundations.append(Gaji_Foundation(x, y, self, -1, base_rank=1))
 
         # Create right foundations
         x = self.width - l.XS * 2
         s.foundations.append(Gaji_Foundation(x, y, self, -1, base_rank=2))
-        x = x + l.XS
+        x += l.XS
         s.foundations.append(Gaji_Foundation(x, y, self, -1, base_rank=3))
 
         # Create row stacks
         x = l.XS * 2.5 + l.XM
         for i in range(8):
-            s.rows.append(Gaji_RowStack(x, y, self, yoffset=l.CH/2,
-                            max_cards=12, max_accept=12))
-            x = x + l.XS
-        self.setRegion(s.rows, (l.XM + l.XS * 2, -999, l.XM + l.XS * 10, 999999))
+            s.rows.append(Gaji_RowStack(x, y, self, yoffset=l.CH//2,
+                                        max_cards=12, max_accept=12))
+            x += l.XS
+        self.setRegion(
+            s.rows, (l.XM + l.XS * 2, -999, l.XM + l.XS * 10, 999999))
 
         # Create talon
-        s.talon = InitialDealTalonStack(self.width - l.XS, self.height - l.YS, self)
+        s.talon = InitialDealTalonStack(
+            self.width - l.XS, self.height - l.YS, self)
 
         # Define stack groups
         l.defaultStackGroups()
@@ -170,9 +193,7 @@ class Gaji(AbstractFlowerGame):
 
     def startGame(self):
         assert len(self.s.talon.cards) == 48
-        for i in range(4):
-            self.s.talon.dealRow(frames=0)
-        self.startDealSample()
+        self._startDealNumRows(4)
         r = self.s.rows
         self.s.talon.dealRow(rows=(r[0], r[1], r[2], r[5], r[6], r[7]))
         self.s.talon.dealRow(rows=(r[0], r[1], r[6], r[7]))
@@ -188,14 +209,13 @@ class Gaji(AbstractFlowerGame):
 
     def shallHighlightMatch(self, stack1, card1, stack2, card2):
         if stack1 in self.s.foundations:
-            return (card1.rank == card2.rank
-                    and ((((card1.suit + 1) % 12) == card2.suit)
-                    or (((card1.suit - 1) % 12) == card2.suit)))
+            return (card1.rank == card2.rank and
+                    ((((card1.suit + 1) % 12) == card2.suit) or
+                     (((card1.suit - 1) % 12) == card2.suit)))
         else:
-            return ((card1.suit == card2.suit)
-                    and ((card1.rank + 1 == card2.rank)
-                    or (card1.rank - 1 == card2.rank)))
-
+            return ((card1.suit == card2.suit) and
+                    ((card1.rank + 1 == card2.rank) or
+                     (card1.rank - 1 == card2.rank)))
 
 
 # ************************************************************************
@@ -203,7 +223,7 @@ class Gaji(AbstractFlowerGame):
 #  ***********************************************************************/
 
 class Oonsoo(AbstractFlowerGame):
-    Layout_Method = Layout.oonsooLayout
+    Layout_Method = staticmethod(Layout.oonsooLayout)
     Talon_Class = DealRowTalonStack
     RowStack_Class = Oonsoo_SequenceStack
     Rows = 12
@@ -247,13 +267,12 @@ class Oonsoo(AbstractFlowerGame):
         if len(self.s.talon.cards):
             return 0
         for s in self.s.rows:
-            if (len(s.cards) != 4 or not cardsFaceUp(s.cards)
-                    or not s.isHanafudaSequence(s.cards, self.Strictness)):
+            if (len(s.cards) != 4 or not cardsFaceUp(s.cards) or
+                    not s.isHanafudaSequence(s.cards, self.Strictness)):
                 return 0
         return 1
 
 
-
 # ************************************************************************
 # * Oonsoo Too
 # ************************************************************************
@@ -262,7 +281,6 @@ class OonsooToo(Oonsoo):
     Reserves = 1
 
 
-
 # ************************************************************************
 # * Oonsoo Strict
 # ************************************************************************
@@ -273,7 +291,6 @@ class OonsooStrict(Oonsoo):
     Strictness = 1
 
 
-
 # ************************************************************************
 # * Oonsoo Open
 # ************************************************************************
@@ -282,7 +299,6 @@ class OonsooOpen(Oonsoo):
     BaseRank = ANY_RANK
 
 
-
 # ************************************************************************
 # * Oonsoo Times Two
 # ************************************************************************
@@ -292,7 +308,6 @@ class OonsooTimesTwo(Oonsoo):
     Reserves = 1
 
 
-
 # ************************************************************************
 #  * Pagoda
 #  ***********************************************************************/
@@ -311,33 +326,36 @@ class Pagoda(AbstractFlowerGame):
         self.setSize(l.XM + l.XS * 11, l.YS * 6)
 
         # Create foundations
-        self.foundation_texts = []
         id = 0
         for j in range(4):
             x, y = l.XM + l.XS * 8, l.YM * 3 + l.YS * j * 1.5
             for i in range(3):
-                s.foundations.append(Pagoda_Foundation(x, y, self, id))
-                t = MfxCanvasText(self.canvas, x + l.CW / 2, y - 12,
+                stack = Pagoda_Foundation(x, y, self, id)
+                s.foundations.append(stack)
+                t = MfxCanvasText(self.canvas, x + l.CW // 2, y - 12,
                                   anchor="center", font=font)
-                self.foundation_texts.append(t)
+                stack.texts.misc = t
                 x = x + l.XS
                 id = id + 1
 
         # Build pagoda
         x, y = l.XM + l.XS, l.YM
-        d = ( 0.4, 0.25, 0, 0.25, 0.4 )
+        d = (0.4, 0.25, 0, 0.25, 0.4)
         for i in range(5):
-            s.reserves.append(ReserveStack(x + l.XS * i, y + l.YS * d[i], self))
+            s.reserves.append(
+                ReserveStack(x + l.XS * i, y + l.YS * d[i], self))
 
         x, y = l.XM + l.XS * 2, y + l.YS * 1.1
-        d = ( 0.25, 0, 0.25 )
+        d = (0.25, 0, 0.25)
         for i in range(3):
-            s.reserves.append(ReserveStack(x + l.XS * i, y + l.YS * d[i], self))
+            s.reserves.append(
+                ReserveStack(x + l.XS * i, y + l.YS * d[i], self))
 
         x, y = l.XM, y + l.YS * 1.1
-        d = ( 0.5, 0.4, 0.25, 0, 0.25, 0.4, 0.5 )
+        d = (0.5, 0.4, 0.25, 0, 0.25, 0.4, 0.5)
         for i in range(7):
-            s.reserves.append(ReserveStack(x + l.XS * i, y + l.YS * d[i], self))
+            s.reserves.append(
+                ReserveStack(x + l.XS * i, y + l.YS * d[i], self))
 
         x, y = l.XM + l.XS, y + l.YS * 1.5
         for i in range(5):
@@ -370,7 +388,7 @@ class Pagoda(AbstractFlowerGame):
                 text = _("Rising")
             else:
                 text = _("Setting")
-            self.foundation_texts[i].config(text=text)
+            s.texts.misc.config(text=text)
 
     #
     # Game over rides
@@ -389,7 +407,6 @@ class Pagoda(AbstractFlowerGame):
                 self.dealCards()
 
 
-
 # ************************************************************************
 #  * Matsukiri
 #  ***********************************************************************/
@@ -411,18 +428,20 @@ class MatsuKiri(AbstractFlowerGame):
         x = l.XM
         y = l.YM
         for i in range(8):
-            s.rows.append(Matsukiri_RowStack(x, y, self, yoffset=l.CH/2,
-                            max_cards=12, max_accept=12))
+            s.rows.append(Matsukiri_RowStack(x, y, self, yoffset=l.CH//2,
+                                             max_cards=12, max_accept=12))
             x = x + l.XS
         self.setRegion(s.rows, (-999, -999, l.XM + (l.XS * 8) + 10, 999999))
 
         # Create foundation
         x = x + l.XM * 2
         s.foundations.append(MatsuKiri_Foundation(x, y, self, ANY_SUIT))
-        self.setRegion(s.foundations, (l.XM + (l.XS * 8) + 10, -999, 999999, 999999))
+        self.setRegion(
+            s.foundations, (l.XM + (l.XS * 8) + 10, -999, 999999, 999999))
 
         # Create talon
-        s.talon = InitialDealTalonStack(self.width - l.XS, self.height - l.YS, self)
+        s.talon = InitialDealTalonStack(
+            self.width - l.XS, self.height - l.YS, self)
 
         # Define stack groups
         l.defaultStackGroups()
@@ -433,9 +452,7 @@ class MatsuKiri(AbstractFlowerGame):
 
     def startGame(self):
         assert len(self.s.talon.cards) == 48
-        for i in range(5):
-            self.s.talon.dealRow(frames=0)
-        self.startDealSample()
+        self._startDealNumRows(5)
         self.s.talon.dealRow()
         assert len(self.s.talon.cards) == 0
 
@@ -468,25 +485,28 @@ class GreatWall(AbstractFlowerGame):
         self.setSize(w, h)
 
         # Create foundations
-        self.foundation_texts = []
-        x, y = (l.XM, l.XM, w - l.XS, w - l.XS), (l.YM, h / 2, l.YM, h / 2)
+        x, y = (l.XM, l.XM, w - l.XS, w - l.XS), (l.YM, h // 2, l.YM, h // 2)
         for i in range(4):
-            s.foundations.append(GreatWall_FoundationStack(x[i], y[i] + l.YM, self, -1, base_rank=i))
-            self.foundation_texts.append(MfxCanvasText(self.canvas,
-                                                       x[i] + l.CW / 2, y[i],
-                                                       anchor="center", font=font))
+            stack = GreatWall_FoundationStack(x[i], y[i] + l.YM, self, -1,
+                                              base_rank=i)
+            s.foundations.append(stack)
+            stack.texts.misc = MfxCanvasText(self.canvas,
+                                             x[i] + l.CW // 2, y[i],
+                                             anchor="center", font=font)
 
         # Create row stacks
         x = l.XM + l.XS * 1.5
         y = l.YM
         for i in range(12):
-            s.rows.append(GreatWall_RowStack(x, y, self, yoffset=l.CH/4,
-                                                max_cards=26, max_accept=26))
+            s.rows.append(GreatWall_RowStack(x, y, self, yoffset=l.CH//4,
+                                             max_cards=26, max_accept=26))
             x = x + l.XS
-        self.setRegion(s.rows, (l.XM + l.XS * 1.25, -999, self.width - l.XS * 1.25, 999999))
+        self.setRegion(
+            s.rows, (l.XM + l.XS * 1.25, -999, self.width - l.XS * 1.25,
+                     999999))
 
         # Create talon
-        x = self.width / 2 - l.CW / 2
+        x = self.width // 2 - l.CW // 2
         y = self.height - l.YS * 1.2
         s.talon = InitialDealTalonStack(x, y, self)
 
@@ -501,14 +521,17 @@ class GreatWall(AbstractFlowerGame):
         if self.preview > 1:
             return
         for i in range(4):
-            l = len(self.s.foundations[i].cards) / 12
-            if l == 0:
-                t = ""
-            elif l == 4:
-                t = _("Filled")
+            stack = self.s.foundations[i]
+            mylen = len(stack.cards) // 12
+            if mylen == 0:
+                text = ""
+            elif mylen == 4:
+                text = _("Filled")
             else:
-                t = str(l) + (_("st"), _("nd"), _("rd"), _("th"))[l - 1] + _(" Deck")
-            self.foundation_texts[i].config(text=str(t))
+                text = str(mylen) + \
+                    (_("st"), _("nd"), _("rd"), _("th"))[mylen - 1] \
+                    + _(" Deck")
+            stack.texts.misc.config(text=text)
 
     #
     # Game over rides
@@ -519,8 +542,7 @@ class GreatWall(AbstractFlowerGame):
         self.updateText()
         for i in range(15):
             self.s.talon.dealRow(flip=0, frames=0)
-        self.startDealSample()
-        self.s.talon.dealRow()
+        self._startAndDealRow()
         assert len(self.s.talon.cards) == 0
 
     def fillStack(self, stack):
@@ -530,13 +552,12 @@ class GreatWall(AbstractFlowerGame):
 
     def shallHighlightMatch(self, stack1, card1, stack2, card2):
         if stack1 in self.s.foundations:
-            return (card1.rank == card2.rank
-                    and ((((card1.suit + 1) % 12) == card2.suit)
-                    or (((card1.suit - 1) % 12) == card2.suit)))
+            return (card1.rank == card2.rank and
+                    ((((card1.suit + 1) % 12) == card2.suit) or
+                     (((card1.suit - 1) % 12) == card2.suit)))
         else:
-            return (card1.rank + 1 == card2.rank
-                    or card1.rank - 1 == card2.rank)
-
+            return (card1.rank + 1 == card2.rank or
+                    card1.rank - 1 == card2.rank)
 
 
 # ************************************************************************
@@ -568,11 +589,14 @@ class FourWinds(AbstractFlowerGame):
         for i in range(4):
             x0 = x + (xoffset[i] * l.XS)
             y0 = y + (yoffset[i] * l.YS)
-            s.foundations.append(FourWinds_Foundation(x0, y0, self, -1,
-                                    max_cards=12, max_accept=1, base_rank=i))
-            t = MfxCanvasText(self.canvas, x0 + l.CW / 2, y0 + l.YS + 5,
+            stack = FourWinds_Foundation(x0, y0, self, -1,
+                                         max_cards=12, max_accept=1,
+                                         base_rank=i)
+            s.foundations.append(stack)
+            t = MfxCanvasText(self.canvas, x0 + l.CW // 2, y0 + l.YS + 5,
                               anchor="center", font=font,
                               text=TEXTS[i])
+            stack.texts.misc = t
 
         # Create rows
         xoffset = (1.25, 3.75, 3.75, 1.25)
@@ -580,12 +604,16 @@ class FourWinds(AbstractFlowerGame):
         for i in range(4):
             x0 = x + (xoffset[i] * l.XS)
             y0 = y + (yoffset[i] * l.YS)
-            s.rows.append(FourWinds_RowStack(x0, y0, self, yoffset=10,
-                                    max_cards=3, max_accept=1, base_rank=ANY_RANK))
-            t = MfxCanvasText(self.canvas, x0 + l.CW / 2, y0 + l.YS + 5,
+            stack = FourWinds_RowStack(x0, y0, self, yoffset=10,
+                                       max_cards=3, max_accept=1,
+                                       base_rank=ANY_RANK)
+            s.rows.append(stack)
+            t = MfxCanvasText(self.canvas, x0 + l.CW // 2, y0 + l.YS + 5,
                               anchor="center", font=font,
                               text=TEXTS[i+4])
-        self.setRegion(s.rows, (x + l.XS, y + l.YS * 0.65, x + l.XS * 4 + 5, y + l.YS * 3 + 5))
+            stack.texts.misc = t
+        self.setRegion(s.rows, (x + l.XS, y + l.YS * 0.65, x + l.XS * 4 + 5,
+                                y + l.YS * 3 + 5))
 
         # Create talon
         x = x + 2 * l.XS
@@ -614,13 +642,12 @@ class FourWinds(AbstractFlowerGame):
                 self.dealCards()
 
 
-
 # ************************************************************************
 # * Sumo
 # ************************************************************************
 
 class Sumo(AbstractFlowerGame):
-    Layout_Method = Layout.sumoLayout
+    Layout_Method = staticmethod(Layout.sumoLayout)
     Talon_Class = InitialDealTalonStack
     Foundation_Class = Hanafuda_SS_FoundationStack
     RowStack_Class = Hanafuda_SequenceStack
@@ -639,10 +666,13 @@ class Sumo(AbstractFlowerGame):
         # Create stacks
         s.talon = self.Talon_Class(l.s.talon.x, l.s.talon.y, self)
         for r in l.s.foundations:
-            s.foundations.append(self.Foundation_Class(r.x, r.y, self,
-                                    suit=r.suit, base_rank=3))
+            s.foundations.append(
+                self.Foundation_Class(
+                    r.x, r.y, self,
+                    suit=r.suit, base_rank=3))
         for r in l.s.rows:
-            s.rows.append(self.RowStack_Class(r.x, r.y, self, yoffset=l.YOFFSET))
+            s.rows.append(
+                self.RowStack_Class(r.x, r.y, self, yoffset=l.YOFFSET))
         for r in l.s.reserves:
             s.reserves.append(ReserveStack(r.x, r.y, self))
         l.defaultAll()
@@ -653,12 +683,7 @@ class Sumo(AbstractFlowerGame):
 
     def startGame(self):
         assert len(self.s.talon.cards) == 48
-        for i in range(5):
-            self.s.talon.dealRow(frames=0)
-        self.startDealSample()
-        self.s.talon.dealRow()
-        self.s.talon.dealCards()
-
+        self._startDealNumRowsAndDealRowAndCards(5)
 
 
 # ************************************************************************
@@ -666,7 +691,7 @@ class Sumo(AbstractFlowerGame):
 # ************************************************************************
 
 class BigSumo(AbstractFlowerGame):
-    Layout_Method = Layout.sumoLayout
+    Layout_Method = staticmethod(Layout.sumoLayout)
     Talon_Class = InitialDealTalonStack
     Foundation_Class = Hanafuda_SS_FoundationStack
     RowStack_Class = Hanafuda_SequenceStack
@@ -684,10 +709,12 @@ class BigSumo(AbstractFlowerGame):
         # Create stacks
         s.talon = self.Talon_Class(l.s.talon.x, l.s.talon.y, self)
         for r in l.s.foundations:
-            s.foundations.append(self.Foundation_Class(r.x, r.y, self,
-                                    suit=r.suit, base_rank=3))
+            s.foundations.append(
+                self.Foundation_Class(r.x, r.y, self,
+                                      suit=r.suit, base_rank=3))
         for r in l.s.rows:
-            s.rows.append(self.RowStack_Class(r.x, r.y, self, yoffset=l.YOFFSET))
+            s.rows.append(
+                self.RowStack_Class(r.x, r.y, self, yoffset=l.YOFFSET))
         for r in l.s.reserves:
             s.reserves.append(ReserveStack(r.x, r.y, self))
         l.defaultAll()
@@ -698,20 +725,17 @@ class BigSumo(AbstractFlowerGame):
 
     def startGame(self):
         assert len(self.s.talon.cards) == 48 * 2
-        for i in range(9):
-            self.s.talon.dealRow(frames=0)
-        self.startDealSample()
+        self._startDealNumRows(9)
         self.s.talon.dealRow(rows=self.s.rows[2:8])
         self.s.talon.dealCards()
 
 
-
 # ************************************************************************
 # * Samuri
 # ************************************************************************
 
 class Samuri(AbstractFlowerGame):
-    Layout_Method = Layout.samuriLayout
+    Layout_Method = staticmethod(Layout.samuriLayout)
     Talon_Class = WasteTalonStack
     Foundation_Class = Hanafuda_SS_FoundationStack
     RowStack_Class = Hanafuda_SequenceStack
@@ -729,22 +753,22 @@ class Samuri(AbstractFlowerGame):
 
         # Create stacks
         s.talon = self.Talon_Class(l.s.talon.x, l.s.talon.y, self,
-                            max_rounds=max_rounds, num_deal=num_deal)
+                                   max_rounds=max_rounds, num_deal=num_deal)
         s.waste = WasteStack(l.s.waste.x, l.s.waste.y, self)
 
         # Create foundations
         for r in l.s.foundations:
             s.foundations.append(self.Foundation_Class(r.x, r.y, self,
-                                    suit=r.suit, base_rank=3))
+                                 suit=r.suit, base_rank=3))
 
         # Create row stacks
         for r in l.s.rows:
-            s.rows.append(self.RowStack_Class(r.x, r.y, self, yoffset=l.YOFFSET))
+            s.rows.append(
+                self.RowStack_Class(r.x, r.y, self, yoffset=l.YOFFSET))
 
         # Define stack groups
         l.defaultAll()
 
-
     #
     # Game over rides
     #
@@ -756,7 +780,8 @@ class Samuri(AbstractFlowerGame):
             self.s.talon.dealRow(flip=0, frames=0)
         max_row = len(self.s.rows)
         for i in range(max_row):
-            self.s.talon.dealRow(rows=self.s.rows[i:max_row-i], flip=0, frames=0)
+            self.s.talon.dealRow(
+                rows=self.s.rows[i:max_row-i], flip=0, frames=0)
         self.startDealSample()
         self.s.talon.dealRow()
         self.s.talon.dealCards()
@@ -767,7 +792,6 @@ class Samuri(AbstractFlowerGame):
                 self.dealCards()
 
 
-
 # ************************************************************************
 #  * Double Samuri
 #  ***********************************************************************/
@@ -776,7 +800,6 @@ class DoubleSamuri(Samuri):
     Rows = 11
 
 
-
 # ************************************************************************
 #  * Super Samuri
 #  ***********************************************************************/
@@ -785,13 +808,12 @@ class SuperSamuri(DoubleSamuri):
     pass
 
 
-
 # ************************************************************************
 # * Little Easy
 # ************************************************************************
 
 class LittleEasy(AbstractFlowerGame):
-    Layout_Method = Layout.easyLayout
+    Layout_Method = staticmethod(Layout.easyLayout)
     Talon_Class = WasteTalonStack
     Foundation_Class = FourWinds_Foundation
     RowStack_Class = Hanafuda_SequenceStack
@@ -804,19 +826,21 @@ class LittleEasy(AbstractFlowerGame):
 
     def createGame(self, max_rounds=-1, num_deal=3, **layout):
         l, s = Layout(self), self.s
-        kwdefault(layout, rows=self.Rows, waste=1, texts=1, playcards=self.PlayCards)
+        kwdefault(layout, rows=self.Rows, waste=1, texts=1,
+                  playcards=self.PlayCards)
         self.Layout_Method(l, **layout)
         self.setSize(l.size[0], l.size[1])
 
         # Create stacks
         s.talon = self.Talon_Class(l.s.talon.x, l.s.talon.y, self,
-                            max_rounds=max_rounds, num_deal=num_deal)
+                                   max_rounds=max_rounds, num_deal=num_deal)
         s.waste = WasteStack(l.s.waste.x, l.s.waste.y, self)
         for r in l.s.foundations:
             s.foundations.append(self.Foundation_Class(r.x, r.y, self,
-                                    suit=ANY_SUIT, base_rank=r.suit))
+                                 suit=ANY_SUIT, base_rank=r.suit))
         for r in l.s.rows:
-            s.rows.append(self.RowStack_Class(r.x, r.y, self, yoffset=l.YOFFSET))
+            s.rows.append(
+                self.RowStack_Class(r.x, r.y, self, yoffset=l.YOFFSET))
         l.defaultAll()
 
     #
@@ -836,7 +860,6 @@ class LittleEasy(AbstractFlowerGame):
                 self.dealCards()
 
 
-
 # ************************************************************************
 # * Easy x One
 # ************************************************************************
@@ -847,7 +870,6 @@ class EasyX1(LittleEasy):
         LittleEasy.createGame(self, max_rounds=2, num_deal=1)
 
 
-
 # ************************************************************************
 # * Relax
 # ************************************************************************
@@ -856,7 +878,6 @@ class Relax(EasyX1):
     RowStack_Class = Oonsoo_SequenceStack
 
 
-
 # ************************************************************************
 # * Big Easy
 # ************************************************************************
@@ -865,7 +886,6 @@ class BigEasy(LittleEasy):
     Rows = 11
 
 
-
 # ************************************************************************
 # * Easy Supreme
 # ************************************************************************
@@ -875,13 +895,12 @@ class EasySupreme(LittleEasy):
     PlayCards = 14
 
 
-
 # ************************************************************************
 # * Just For Fun
 # ************************************************************************
 
 class JustForFun(AbstractFlowerGame):
-    Layout_Method = Layout.funLayout
+    Layout_Method = staticmethod(Layout.funLayout)
     Talon_Class = InitialDealTalonStack
     Foundation_Class = FourWinds_Foundation
     RowStack_Class = Hanafuda_SequenceStack
@@ -895,7 +914,8 @@ class JustForFun(AbstractFlowerGame):
 
     def createGame(self, **layout):
         l, s = Layout(self), self.s
-        kwdefault(layout, rows=self.Rows, reserves=self.Reserves, texts=0, playcards=22)
+        kwdefault(layout, rows=self.Rows, reserves=self.Reserves, texts=0,
+                  playcards=22)
         self.Layout_Method(l, **layout)
         self.setSize(l.size[0], l.size[1])
 
@@ -903,10 +923,10 @@ class JustForFun(AbstractFlowerGame):
         s.talon = self.Talon_Class(l.s.talon.x, l.s.talon.y, self)
         for r in l.s.foundations:
             s.foundations.append(self.Foundation_Class(r.x, r.y, self,
-                                    suit=ANY_SUIT, base_rank=r.suit))
+                                 suit=ANY_SUIT, base_rank=r.suit))
         for r in l.s.rows:
             s.rows.append(self.RowStack_Class(r.x, r.y, self,
-                            base_rank=self.BaseRank, yoffset=l.YOFFSET))
+                          base_rank=self.BaseRank, yoffset=l.YOFFSET))
         for r in l.s.reserves:
             s.reserves.append(ReserveStack(r.x, r.y, self))
         l.defaultAll()
@@ -925,7 +945,6 @@ class JustForFun(AbstractFlowerGame):
         self.s.talon.dealCards()
 
 
-
 # ************************************************************************
 # * Double Your Fun
 # ************************************************************************
@@ -935,7 +954,6 @@ class DoubleYourFun(JustForFun):
     Reserves = 4
 
 
-
 # ************************************************************************
 # * Firecracker
 # ************************************************************************
@@ -946,7 +964,6 @@ class Firecracker(JustForFun):
     BaseRank = ANY_RANK
 
 
-
 # ************************************************************************
 # * Cherry Bomb
 # ************************************************************************
@@ -955,13 +972,12 @@ class CherryBomb(Firecracker):
     Rows = 18
 
 
-
 # ************************************************************************
 # * Paulownia
 # ************************************************************************
 
 class Paulownia(AbstractFlowerGame):
-    Layout_Method = Layout.klondikeLayout
+    Layout_Method = staticmethod(Layout.klondikeLayout)
     Talon_Class = WasteTalonStack
     Foundation_Class = Hanafuda_SS_FoundationStack
     RowStack_Class = Hanafuda_SequenceStack
@@ -978,18 +994,19 @@ class Paulownia(AbstractFlowerGame):
 
         # Create talon
         s.talon = self.Talon_Class(l.s.talon.x, l.s.talon.y, self,
-                            max_rounds=max_rounds, num_deal=num_deal)
+                                   max_rounds=max_rounds, num_deal=num_deal)
         s.waste = WasteStack(l.s.waste.x, l.s.waste.y, self)
 
         # Create foundations
         for r in l.s.foundations:
             s.foundations.append(self.Foundation_Class(r.x, r.y, self,
-                                        suit=r.suit, base_rank=3))
+                                                       suit=r.suit,
+                                                       base_rank=3))
 
         # Create row stacks
         for r in l.s.rows:
             s.rows.append(self.RowStack_Class(r.x, r.y, self,
-                            base_rank = 0, yoffset=l.YOFFSET))
+                          base_rank=0, yoffset=l.YOFFSET))
 
         # Define stack groups
         l.defaultAll()
@@ -1007,7 +1024,6 @@ class Paulownia(AbstractFlowerGame):
         self.s.talon.dealCards()
 
 
-
 # ************************************************************************
 # *  Register the games
 # ************************************************************************
@@ -1015,19 +1031,24 @@ class Paulownia(AbstractFlowerGame):
 def r(id, gameclass, name, game_type, decks, redeals, skill_level):
     game_type = game_type | GI.GT_HANAFUDA
     gi = GameInfo(id, gameclass, name, game_type, decks, redeals, skill_level,
-                  suits=range(12), ranks=range(4))
+                  suits=list(range(12)), ranks=list(range(4)))
     registerGame(gi)
     return gi
 
+
 r(12345, Oonsoo, "Oonsoo", GI.GT_HANAFUDA, 1, 0, GI.SL_MOSTLY_SKILL)
-r(12346, MatsuKiri, "MatsuKiri", GI.GT_HANAFUDA | GI.GT_OPEN, 1, 0, GI.SL_MOSTLY_SKILL)
-r(12372, MatsuKiriStrict, 'MatsuKiri Strict', GI.GT_HANAFUDA | GI.GT_OPEN, 1, 0, GI.SL_MOSTLY_SKILL)
+r(12346, MatsuKiri, "MatsuKiri", GI.GT_HANAFUDA | GI.GT_OPEN, 1, 0,
+  GI.SL_MOSTLY_SKILL)
+r(12372, MatsuKiriStrict, 'MatsuKiri Strict', GI.GT_HANAFUDA | GI.GT_OPEN, 1,
+  0, GI.SL_MOSTLY_SKILL)
 r(12347, Gaji, "Gaji", GI.GT_HANAFUDA | GI.GT_OPEN, 1, 0, GI.SL_MOSTLY_SKILL)
-r(12348, FlowerClock, "Flower Clock", GI.GT_HANAFUDA | GI.GT_OPEN, 1, 0, GI.SL_MOSTLY_SKILL)
+r(12348, FlowerClock, "Flower Clock", GI.GT_HANAFUDA | GI.GT_OPEN, 1, 0,
+  GI.SL_MOSTLY_SKILL)
 r(12349, Pagoda, "Pagoda", GI.GT_HANAFUDA, 2, 0, GI.SL_BALANCED)
 r(12350, Samuri, "Samuri", GI.GT_HANAFUDA, 1, 0, GI.SL_BALANCED)
 r(12351, GreatWall, "Great Wall", GI.GT_HANAFUDA, 4, 0, GI.SL_MOSTLY_SKILL)
-r(12352, FourWinds, "Hanafuda Four Winds", GI.GT_HANAFUDA, 1, 1, GI.SL_MOSTLY_SKILL)
+r(12352, FourWinds, "Hanafuda Four Winds", GI.GT_HANAFUDA, 1, 1,
+  GI.SL_MOSTLY_SKILL)
 r(12353, Sumo, "Sumo", GI.GT_HANAFUDA, 1, 0, GI.SL_MOSTLY_SKILL)
 r(12354, BigSumo, "Big Sumo", GI.GT_HANAFUDA, 2, 0, GI.SL_MOSTLY_SKILL)
 r(12355, LittleEasy, "Little Easy", GI.GT_HANAFUDA, 1, -1, GI.SL_BALANCED)
@@ -1039,11 +1060,14 @@ r(12360, EasyX1, "Easy x One", GI.GT_HANAFUDA, 1, 1, GI.SL_BALANCED)
 r(12361, Relax, "Relax", GI.GT_HANAFUDA, 1, 1, GI.SL_BALANCED)
 r(12362, DoubleSamuri, "Double Samuri", GI.GT_HANAFUDA, 2, 0, GI.SL_BALANCED)
 r(12363, SuperSamuri, "Super Samuri", GI.GT_HANAFUDA, 4, 0, GI.SL_BALANCED)
-r(12364, DoubleYourFun, "Double Your Fun", GI.GT_HANAFUDA, 2, 0, GI.SL_MOSTLY_SKILL)
+r(12364, DoubleYourFun, "Double Your Fun", GI.GT_HANAFUDA, 2, 0,
+  GI.SL_MOSTLY_SKILL)
 r(12365, CherryBomb, "Cherry Bomb", GI.GT_HANAFUDA, 2, 0, GI.SL_BALANCED)
 r(12366, OonsooToo, "Oonsoo Too", GI.GT_HANAFUDA, 1, 0, GI.SL_MOSTLY_SKILL)
-r(12367, OonsooStrict, "Oonsoo Strict", GI.GT_HANAFUDA, 1, 0, GI.SL_MOSTLY_SKILL)
+r(12367, OonsooStrict, "Oonsoo Strict", GI.GT_HANAFUDA, 1, 0,
+  GI.SL_MOSTLY_SKILL)
 r(12368, OonsooOpen, "Oonsoo Open", GI.GT_HANAFUDA, 1, 0, GI.SL_MOSTLY_SKILL)
-r(12379, OonsooTimesTwo, "Oonsoo Times Two", GI.GT_HANAFUDA, 2, 0, GI.SL_MOSTLY_SKILL)
+r(12379, OonsooTimesTwo, "Oonsoo Times Two", GI.GT_HANAFUDA, 2, 0,
+  GI.SL_MOSTLY_SKILL)
 
 del r
