@@ -1,65 +1,70 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python
 # -*- mode: python; coding: utf-8; -*-
-##---------------------------------------------------------------------------##
-##
-## Copyright (C) 1998-2003 Markus Franz Xaver Johannes Oberhumer
-## Copyright (C) 2003 Mt. Hood Playing Card Co.
-## Copyright (C) 2005-2009 Skomoroh
-##
-## This program is free software: you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation, either version 3 of the License, or
-## (at your option) any later version.
-##
-## This program is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
-##
-## You should have received a copy of the GNU General Public License
-## along with this program.  If not, see <http://www.gnu.org/licenses/>.
-##
-##---------------------------------------------------------------------------##
-
+# ---------------------------------------------------------------------------##
+#
+#  Copyright (C) 1998-2003 Markus Franz Xaver Johannes Oberhumer
+#  Copyright (C) 2003 Mt. Hood Playing Card Co.
+#  Copyright (C) 2005-2009 Skomoroh
+#
+#  This program is free software: you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation, either version 3 of the License, or
+#  (at your option) any later version.
+#
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#
+#  You should have received a copy of the GNU General Public License
+#  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# ---------------------------------------------------------------------------##
 
 # imports
-import sys, os, time, types, locale
+import re
+import sys
+import os
+import time
+import locale
 import webbrowser
+from six import print_
 
-try:
-    from cPickle import Pickler, Unpickler, UnpicklingError
-except ImportError:
-    from pickle import Pickler, Unpickler, UnpicklingError
+from pickle import Pickler, Unpickler
 
-try:
-    import thread
-except:
-    thread = None
-
-from settings import PACKAGE, TOOLKIT
+from pysollib.settings import PACKAGE, TOOLKIT
 
 Image = ImageTk = ImageOps = None
 if TOOLKIT == 'tk':
-    try: # PIL
+    try:  # PIL
         from PIL import Image
-        from PIL import ImageTk
-        from PIL import ImageOps
+        from PIL import ImageTk  # noqa: F401
+        from PIL import ImageOps  # noqa: F401
     except ImportError:
         Image = None
     else:
         # for py2exe
-        from PIL import GifImagePlugin
-        from PIL import PngImagePlugin
-        from PIL import JpegImagePlugin
-        from PIL import BmpImagePlugin
-        from PIL import PpmImagePlugin
+        from PIL import GifImagePlugin  # noqa: F401
+        from PIL import PngImagePlugin  # noqa: F401
+        from PIL import JpegImagePlugin  # noqa: F401
+        from PIL import BmpImagePlugin  # noqa: F401
+        from PIL import PpmImagePlugin  # noqa: F401
         Image._initialized = 2
+USE_PIL = False
+if TOOLKIT == 'tk' and Image and Image.VERSION >= '1.1.7':
+    USE_PIL = True
 
+if sys.version_info > (3,):
+    unicode = str
+# debug
+# Image = None
+# USE_PIL = False
 
 # ************************************************************************
 # * exceptions
 # ************************************************************************
 
+
 class SubclassResponsibility(Exception):
     pass
 
@@ -70,23 +75,30 @@ class SubclassResponsibility(Exception):
 
 
 def latin1_to_ascii(n):
-    #return n
+    if sys.version_info > (3,):
+        return n
+    # return n
     n = n.encode('iso8859-1', 'replace')
-    ## FIXME: rewrite this for better speed
-    n = (n.replace("\xc4", "Ae")
-         .replace("\xd6", "Oe")
-         .replace("\xdc", "Ue")
-         .replace("\xe4", "ae")
-         .replace("\xf6", "oe")
-         .replace("\xfc", "ue"))
-    return n
+    # FIXME: rewrite this for better speed
+    return (n.replace("\xc4", "Ae")
+             .replace("\xd6", "Oe")
+             .replace("\xdc", "Ue")
+             .replace("\xe4", "ae")
+             .replace("\xf6", "oe")
+             .replace("\xfc", "ue"))
+
+
+def latin1_normalize(n):
+    return re.sub(r"[^\w]", "", latin1_to_ascii(n).lower())
 
 
 def format_time(t):
-    ##print 'format_time:', t
-    if t <= 0: return "0:00"
-    if t < 3600: return "%d:%02d" % (t / 60, t % 60)
-    return "%d:%02d:%02d" % (t / 3600, (t % 3600) / 60, t % 60)
+    # print 'format_time:', t
+    if t <= 0:
+        return "0:00"
+    if t < 3600:
+        return "%d:%02d" % (t // 60, t % 60)
+    return "%d:%02d:%02d" % (t // 3600, (t % 3600) // 60, t % 60)
 
 
 def print_err(s, level=1):
@@ -96,7 +108,10 @@ def print_err(s, level=1):
         ss = PACKAGE+': WARNING:'
     elif level == 2:
         ss = PACKAGE+': DEBUG WARNING:'
-    print >> sys.stderr, ss, s.encode(locale.getpreferredencoding())
+    try:
+        print_(ss, s.encode(locale.getpreferredencoding()), file=sys.stderr)
+    except Exception:
+        print_(ss, s, file=sys.stderr)
     sys.stderr.flush()
 
 
@@ -107,13 +122,20 @@ def print_err(s, level=1):
 def getusername():
     if os.name == "nt":
         return win32_getusername()
-    user = os.environ.get("USER","").strip()
+    user = os.environ.get("USER", "").strip()
     if not user:
-        user = os.environ.get("LOGNAME","").strip()
+        user = os.environ.get("LOGNAME", "").strip()
     return user
 
 
 def getprefdir(package):
+
+    if (TOOLKIT == 'kivy'):
+        from pysollib.kivy.LApp import get_platform
+        plat = get_platform()
+        if plat == 'android':
+            os.environ['HOME'] = '/sdcard'
+
     if os.name == "nt":
         return win32_getprefdir(package)
     home = os.environ.get("HOME", "").strip()
@@ -132,14 +154,16 @@ if os.name == "posix":
 # * MSWin util
 # ************************************************************************
 
+
 def win32_getusername():
-    user = os.environ.get('USERNAME','').strip()
+    user = os.environ.get('USERNAME', '').strip()
     try:
         user = unicode(user, locale.getpreferredencoding())
-    except:
+    except Exception:
         user = ''
     return user
 
+
 def win32_getprefdir(package):
     portprefdir = 'config'      # portable varsion
     if os.path.isdir(portprefdir):
@@ -148,7 +172,7 @@ def win32_getprefdir(package):
     hd = os.environ.get('APPDATA')
     if not hd:
         hd = os.path.expanduser('~')
-        if hd == '~': # win9x
+        if hd == '~':  # win9x
             hd = os.path.abspath('/windows/Application Data')
             if not os.path.exists(hd):
                 hd = os.path.abspath('/')
@@ -160,12 +184,14 @@ def win32_getprefdir(package):
 # ************************************************************************
 
 def destruct(obj):
+    if TOOLKIT == 'kivy':
+        return
+
     # assist in breaking circular references
     if obj is not None:
-        assert isinstance(obj, types.InstanceType)
         for k in obj.__dict__.keys():
             obj.__dict__[k] = None
-            ##del obj.__dict__[k]
+            # del obj.__dict__[k]
 
 
 # ************************************************************************
@@ -260,25 +286,27 @@ def pickle(obj, filename, protocol=0):
     f = None
     try:
         f = open(filename, "wb")
-        p = Pickler(f, protocol)
-        p.dump(obj)
-        f.close(); f = None
-        ##print "Pickled", filename
+        Pickler(f, protocol).dump(obj)
+        f.close()
+        f = None
+        # print "Pickled", filename
     finally:
-        if f: f.close()
+        if f:
+            f.close()
 
 
 def unpickle(filename):
     f, obj = None, None
     try:
         f = open(filename, "rb")
-        p = Unpickler(f)
-        x = p.load()
-        f.close(); f = None
+        x = Unpickler(f).load()
+        f.close()
+        f = None
         obj = x
-        ##print "Unpickled", filename
+        # print "Unpickled", filename
     finally:
-        if f: f.close()
+        if f:
+            f.close()
     return obj
 
 
@@ -291,7 +319,6 @@ def openURL(url):
         webbrowser.open(url)
     except OSError:                  # raised on windows if link is unreadable
         pass
-    except:
-        return 0
-    return 1
-
+    except Exception:
+        return False
+    return True
